import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('update_dataset')
@click.argument("history_id", type=str)
@click.argument("dataset_id", type=str)
@click.option(
    "--annotation",
    help="Replace history dataset annotation with given string",
    type=str
)
@click.option(
    "--deleted",
    help="Mark or unmark history dataset as deleted",
    is_flag=True
)
@click.option(
    "--genome_build",
    help="Replace history dataset genome build (dbkey)",
    type=str
)
@click.option(
    "--name",
    help="Replace history dataset name with the given string",
    type=str
)
@click.option(
    "--visible",
    help="Mark or unmark history dataset as visible",
    is_flag=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, history_id, dataset_id, annotation=None, deleted=None, genome_build=None, name=None, visible=None):
    """Update history dataset metadata. Some of the attributes that can be modified are documented below.

Output:

    details of the updated dataset (for Galaxy release_15.01 and
            earlier only the updated attributes)

        .. warning::
            The return value was changed in BioBlend v0.8.0, previously it was
            the status code (type int).
    """
    kwargs = {}
    if annotation and len(annotation) > 0:
        kwargs['annotation'] = annotation
    if deleted is not None:
        kwargs['deleted'] = deleted
    if genome_build and len(genome_build) > 0:
        kwargs['genome_build'] = genome_build
    if name and len(name) > 0:
        kwargs['name'] = name
    if visible is not None:
        kwargs['visible'] = visible

    return ctx.gi.histories.update_dataset(history_id, dataset_id, **kwargs)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('invoke_workflow')
@click.argument("workflow_id", type=str)
@click.option(
    "--inputs",
    help="A mapping of workflow inputs to datasets and dataset collections. The datasets source can be a LibraryDatasetDatasetAssociation (``ldda``), LibraryDataset (``ld``), HistoryDatasetAssociation (``hda``), or HistoryDatasetCollectionAssociation (``hdca``).",
    type=str
)
@click.option(
    "--params",
    help="A mapping of non-datasets tool parameters (see below)",
    type=str
)
@click.option(
    "--history_id",
    help="The encoded history ID where to store the workflow output. Alternatively, ``history_name`` may be specified to create a new history.",
    type=str
)
@click.option(
    "--history_name",
    help="Create a new history with the given name to store the workflow output. If both ``history_id`` and ``history_name`` are provided, ``history_name`` is ignored. If neither is specified, a new 'Unnamed history' is created.",
    type=str
)
@click.option(
    "--import_inputs_to_history",
    help="If ``True``, used workflow inputs will be imported into the history. If ``False``, only workflow outputs will be visible in the given history.",
    is_flag=True
)
@click.option(
    "--replacement_params",
    help="pattern-based replacements for post-job actions (see below)",
    type=str
)
@click.option(
    "--allow_tool_state_corrections",
    help="If True, allow Galaxy to fill in missing tool state when running workflows. This may be useful for workflows using tools that have changed over time or for workflows built outside of Galaxy with only a subset of inputs defined.",
    is_flag=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, workflow_id, inputs="", params="", history_id="", history_name="", import_inputs_to_history=False, replacement_params="", allow_tool_state_corrections=""):
    """Invoke the workflow identified by ``workflow_id``. This will cause a workflow to be scheduled and return an object describing the workflow invocation.

Output:

    A dict containing the workflow invocation describing the
          scheduling of the workflow. For example::

            {u'history_id': u'2f94e8ae9edff68a',
             u'id': u'df7a1f0c02a5b08e',
             u'inputs': {u'0': {u'id': u'a7db2fac67043c7e',
               u'src': u'hda',
               u'uuid': u'7932ffe0-2340-4952-8857-dbaa50f1f46a'}},
             u'model_class': u'WorkflowInvocation',
             u'state': u'ready',
             u'steps': [{u'action': None,
               u'id': u'd413a19dec13d11e',
               u'job_id': None,
               u'model_class': u'WorkflowInvocationStep',
               u'order_index': 0,
               u'state': None,
               u'update_time': u'2015-10-31T22:00:26',
               u'workflow_step_id': u'cbbbf59e8f08c98c',
               u'workflow_step_label': None,
               u'workflow_step_uuid': u'b81250fd-3278-4e6a-b269-56a1f01ef485'},
              {u'action': None,
               u'id': u'2f94e8ae9edff68a',
               u'job_id': u'e89067bb68bee7a0',
               u'model_class': u'WorkflowInvocationStep',
               u'order_index': 1,
               u'state': u'new',
               u'update_time': u'2015-10-31T22:00:26',
               u'workflow_step_id': u'964b37715ec9bd22',
               u'workflow_step_label': None,
               u'workflow_step_uuid': u'e62440b8-e911-408b-b124-e05435d3125e'}],
             u'update_time': u'2015-10-31T22:00:26',
             u'uuid': u'c8aa2b1c-801a-11e5-a9e5-8ca98228593c',
             u'workflow_id': u'03501d7626bd192f'}

        The ``params`` dict should be specified as follows::

          {STEP_ID: PARAM_DICT, ...}

        where PARAM_DICT is::

          {PARAM_NAME: VALUE, ...}

        For backwards compatibility, the following (deprecated) format is
        also supported for ``params``::

          {TOOL_ID: PARAM_DICT, ...}

        in which case PARAM_DICT affects all steps with the given tool id.
        If both by-tool-id and by-step-id specifications are used, the
        latter takes precedence.

        Finally (again, for backwards compatibility), PARAM_DICT can also
        be specified as::

          {'param': PARAM_NAME, 'value': VALUE}

        Note that this format allows only one parameter to be set per step.

        The ``replacement_params`` dict should map parameter names in
        post-job actions (PJAs) to their runtime values. For
        instance, if the final step has a PJA like the following::

          {u'RenameDatasetActionout_file1': {u'action_arguments': {u'newname': u'${output}'},
            u'action_type': u'RenameDatasetAction',
            u'output_name': u'out_file1'}}

        then the following renames the output dataset to 'foo'::

          replacement_params = {'output': 'foo'}

        see also `this email thread
        <http://lists.bx.psu.edu/pipermail/galaxy-dev/2011-September/006875.html>`_.

        .. warning::
          Historically, the ``run_workflow`` method consumed a ``dataset_map``
          data structure that was indexed by unencoded workflow step IDs. These
          IDs would not be stable across Galaxy instances. The new ``inputs``
          property is instead indexed by either the ``order_index`` property
          (which is stable across workflow imports) or the step UUID which is
          also stable.
    """
    return ctx.gi.workflows.invoke_workflow(workflow_id, inputs=inputs, params=params, history_id=history_id, history_name=history_name, import_inputs_to_history=import_inputs_to_history, replacement_params=replacement_params, allow_tool_state_corrections=allow_tool_state_corrections)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, str_output


@click.command('get_state')
@click.argument("job_id", type=str)
@pass_context
@custom_exception
@str_output
def cli(ctx, job_id):
    """Display the current state for a given job of the current user.

Output:

    state of the given job among the following values: `new`,
          `queued`, `running`, `waiting`, `ok`. If the state cannot be
          retrieved, an empty string is returned.

        .. versionadded:: 0.5.3
    """
    return ctx.gi.jobs.get_state(job_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('update_group')
@click.argument("group_id", type=str)
@click.option(
    "--group_name",
    help="A new name for the group. If None, the group name is not changed.",
    type=str
)
@click.option(
    "--user_ids",
    help="New list of encoded user IDs for the group. It will substitute the previous list of users (with [] if not specified)",
    type=str,
    multiple=True
)
@click.option(
    "--role_ids",
    help="New list of encoded role IDs for the group. It will substitute the previous list of roles (with [] if not specified)",
    type=str,
    multiple=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, group_id, group_name="", user_ids=None, role_ids=None):
    """Update a group.

Output:

    
    """
    return ctx.gi.groups.update_group(group_id, group_name=group_name, user_ids=user_ids, role_ids=role_ids)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, str_output


@click.command('get_user_apikey')
@click.argument("user_id", type=str)
@pass_context
@custom_exception
@str_output
def cli(ctx, user_id):
    """Get the current API key for a given user. This functionality is available since Galaxy ``release_17.01``.

Output:

    the API key for the user
    """
    return ctx.gi.users.get_user_apikey(user_id)



import os
import click



@click.group()
def cli():
    pass

@click.command()
def initdb():
    click.echo('Initialized the database')

@click.command()
def dropdb():
    click.echo('Dropped the database')

cli.add_command(initdb)
cli.add_command(dropdb)

cli()



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('create_dataset_collection')
@click.argument("history_id", type=str)
@click.argument("collection_description")
@pass_context
@custom_exception
@dict_output
def cli(ctx, history_id, collection_description):
    """Create a new dataset collection

Output:

    
    """
    return ctx.gi.histories.create_dataset_collection(history_id, collection_description)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('wait_for_dataset')
@click.argument("library_id", type=str)
@click.argument("dataset_id", type=str)
@click.option(
    "--maxwait",
    help="Total time (in seconds) to wait for the dataset state to become terminal. If the dataset state is not terminal within this time, a ``DatasetTimeoutException`` will be thrown.",
    default="12000",
    show_default=True,
    type=float
)
@click.option(
    "--interval",
    help="Time (in seconds) to wait between 2 consecutive checks.",
    default="3",
    show_default=True,
    type=float
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, library_id, dataset_id, maxwait=12000, interval=3):
    """Wait until the library dataset state is terminal ('ok', 'empty', 'error', 'discarded' or 'failed_metadata').

Output:

    A dictionary containing information about the dataset in the
          library
    """
    return ctx.gi.libraries.wait_for_dataset(library_id, dataset_id, maxwait=maxwait, interval=interval)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('set_permissions')
@click.argument("folder_id", type=str)
@click.option(
    "--action",
    help="action to execute, only \"set_permissions\" is supported.",
    default="set_permissions",
    show_default=True,
    type=str
)
@click.option(
    "--add_ids",
    help="list of role IDs which can add datasets to the folder",
    type=str,
    multiple=True
)
@click.option(
    "--manage_ids",
    help="list of role IDs which can manage datasets in the folder",
    type=str,
    multiple=True
)
@click.option(
    "--modify_ids",
    help="list of role IDs which can modify datasets in the folder",
    type=str,
    multiple=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, folder_id, action="set_permissions", add_ids="", manage_ids="", modify_ids=""):
    """Set the permissions of a folder.

Output:

    dictionary including details of the folder
    """
    return ctx.gi.folders.set_permissions(folder_id, action=action, add_ids=add_ids, manage_ids=manage_ids, modify_ids=modify_ids)



import click
from parsec.commands.groups.add_group_role import cli as func0
from parsec.commands.groups.add_group_user import cli as func1
from parsec.commands.groups.create_group import cli as func2
from parsec.commands.groups.delete_group_role import cli as func3
from parsec.commands.groups.delete_group_user import cli as func4
from parsec.commands.groups.get_group_roles import cli as func5
from parsec.commands.groups.get_group_users import cli as func6
from parsec.commands.groups.get_groups import cli as func7
from parsec.commands.groups.show_group import cli as func8
from parsec.commands.groups.update_group import cli as func9


@click.group()
def cli():
    pass


cli.add_command(func0)
cli.add_command(func1)
cli.add_command(func2)
cli.add_command(func3)
cli.add_command(func4)
cli.add_command(func5)
cli.add_command(func6)
cli.add_command(func7)
cli.add_command(func8)
cli.add_command(func9)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, str_output


@click.command('create_user_apikey')
@click.argument("user_id", type=str)
@pass_context
@custom_exception
@str_output
def cli(ctx, user_id):
    """Create a new API key for a given user.

Output:

    the API key for the user
    """
    return ctx.gi.users.create_user_apikey(user_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('import_shared_workflow')
@click.argument("workflow_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, workflow_id):
    """Imports a new workflow from the shared published workflows.

Output:

    A description of the workflow.
          For example::

            {u'id': u'ee0e2b4b696d9092',
             u'model_class': u'StoredWorkflow',
             u'name': u'Super workflow that solves everything!',
             u'published': False,
             u'tags': [],
             u'url': u'/api/workflows/ee0e2b4b696d9092'}
    """
    return ctx.gi.workflows.import_shared_workflow(workflow_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('update_history')
@click.argument("history_id", type=str)
@click.option(
    "--annotation",
    help="Replace history annotation with given string",
    type=str
)
@click.option(
    "--deleted",
    help="Mark or unmark history as deleted",
    is_flag=True
)
@click.option(
    "--importable",
    help="Mark or unmark history as importable",
    is_flag=True
)
@click.option(
    "--name",
    help="Replace history name with the given string",
    type=str
)
@click.option(
    "--published",
    help="Mark or unmark history as published",
    is_flag=True
)
@click.option(
    "--purged",
    help="If True, mark history as purged (permanently deleted). Ignored on Galaxy release_15.01 and earlier",
    is_flag=True
)
@click.option(
    "--tags",
    help="Replace history tags with the given list",
    type=str,
    multiple=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, history_id, annotation=None, deleted=None, importable=None, name=None, published=None, purged=None, tags=None):
    """Update history metadata information. Some of the attributes that can be modified are documented below.

Output:

    details of the updated history (for Galaxy release_15.01 and
            earlier only the updated attributes)

        .. warning::
            The return value was changed in BioBlend v0.8.0, previously it was
            the status code (type int).
    """
    kwargs = {}
    if annotation and len(annotation) > 0:
        kwargs['annotation'] = annotation
    if deleted is not None:
        kwargs['deleted'] = deleted
    if importable is not None:
        kwargs['importable'] = importable
    if name and len(name) > 0:
        kwargs['name'] = name
    if published is not None:
        kwargs['published'] = published
    if purged is not None:
        kwargs['purged'] = purged

    return ctx.gi.histories.update_history(history_id, tags=tags, **kwargs)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('search_jobs')
@click.argument("job_info", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, job_info):
    """Return jobs for the current user based payload content.

Output:

    
    """
    return ctx.gi.jobs.search_jobs(json_loads(job_info))



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('get_repository_revision_install_info')
@click.argument("name", type=str)
@click.argument("owner", type=str)
@click.argument("changeset_revision", type=str)
@pass_context
@custom_exception
@list_output
def cli(ctx, name, owner, changeset_revision):
    """Return a list of dictionaries of metadata about a certain changeset revision for a single tool.

Output:

    Returns a list of the following dictionaries:

          #. a dictionary defining the repository
          #. a dictionary defining the repository revision (RepositoryMetadata)
          #. a dictionary including the additional information required to
             install the repository

          For example::

                     [{u'deleted': False,
                       u'deprecated': False,
                       u'description': u'Galaxy Freebayes Bayesian genetic variant detector tool',
                       u'homepage_url': u'',
                       u'id': u'491b7a3fddf9366f',
                       u'long_description': u'Galaxy Freebayes Bayesian genetic variant detector tool originally included in the Galaxy code distribution but migrated to the tool shed.',
                       u'name': u'freebayes',
                       u'owner': u'devteam',
                       u'private': False,
                       u'remote_repository_url': u'',
                       u'times_downloaded': 269,
                       u'type': u'unrestricted',
                       u'url': u'/api/repositories/491b7a3fddf9366f',
                       u'user_id': u'1de29d50c3c44272'},
                      {u'changeset_revision': u'd291dc763c4c',
                       u'do_not_test': False,
                       u'downloadable': True,
                       u'has_repository_dependencies': False,
                       u'id': u'504be8aaa652c154',
                       u'includes_datatypes': False,
                       u'includes_tool_dependencies': True,
                       u'includes_tools': True,
                       u'includes_tools_for_display_in_tool_panel': True,
                       u'includes_workflows': False,
                       u'malicious': False,
                       u'repository_id': u'491b7a3fddf9366f',
                       u'url': u'/api/repository_revisions/504be8aaa652c154'},
                      {u'freebayes': [u'Galaxy Freebayes Bayesian genetic variant detector tool',
                        u'http://testtoolshed.g2.bx.psu.edu/repos/devteam/freebayes',
                        u'd291dc763c4c',
                        u'9',
                        u'devteam',
                        {},
                        {u'freebayes/0.9.6_9608597d12e127c847ae03aa03440ab63992fedf': {u'changeset_revision': u'd291dc763c4c',
                          u'name': u'freebayes',
                          u'repository_name': u'freebayes',
                          u'repository_owner': u'devteam',
                          u'type': u'package',
                          u'version': u'0.9.6_9608597d12e127c847ae03aa03440ab63992fedf'},
                         u'samtools/0.1.18': {u'changeset_revision': u'd291dc763c4c',
                          u'name': u'samtools',
                          u'repository_name': u'freebayes',
                          u'repository_owner': u'devteam',
                          u'type': u'package',
                          u'version': u'0.1.18'}}]}]
    """
    return ctx.gi.repositories.get_repository_revision_install_info(name, owner, changeset_revision)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('show_history')
@click.argument("history_id", type=str)
@click.option(
    "--contents",
    help="When ``True``, the complete list of datasets in the given history.",
    is_flag=True
)
@click.option(
    "--deleted",
    help="Used when contents=True, includes deleted datasets in history dataset list",
    type=str
)
@click.option(
    "--visible",
    help="Used when contents=True, includes only visible datasets in history dataset list",
    type=str
)
@click.option(
    "--details",
    help="Used when contents=True, includes dataset details. Set to 'all' for the most information",
    type=str
)
@click.option(
    "--types",
    help="???",
    type=str
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, history_id, contents=False, deleted="", visible="", details="", types=""):
    """Get details of a given history. By default, just get the history meta information.

Output:

    details of the given history
    """
    return ctx.gi.histories.show_history(history_id, contents=contents, deleted=deleted, visible=visible, details=details, types=types)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('show_workflow')
@click.argument("workflow_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, workflow_id):
    """Display information needed to run a workflow.

Output:

    A description of the workflow and its inputs.
          For example::

            {u'id': u'92c56938c2f9b315',
             u'inputs': {u'23': {u'label': u'Input Dataset', u'value': u''}},
             u'name': u'Simple',
             u'url': u'/api/workflows/92c56938c2f9b315'}
    """
    return ctx.gi.workflows.show_workflow(workflow_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('get_roles')
@pass_context
@custom_exception
@list_output
def cli(ctx):
    """Displays a collection (list) of roles.

Output:

    A list of dicts with details on individual roles.
          For example::

            [{"id": "f2db41e1fa331b3e",
              "model_class": "Role",
              "name": "Foo",
              "url": "/api/roles/f2db41e1fa331b3e"},
             {"id": "f597429621d6eb2b",
              "model_class": "Role",
              "name": "Bar",
              "url": "/api/roles/f597429621d6eb2b"}]
    """
    return ctx.gi.roles.get_roles()



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('show_user')
@click.argument("user_id", type=str)
@click.option(
    "--deleted",
    help="whether to return results for a deleted user",
    is_flag=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, user_id, deleted=False):
    """Display information about a user.

Output:

    a dictionary containing information about the user
    """
    return ctx.gi.users.show_user(user_id, deleted=deleted)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('delete_folder')
@click.argument("folder_id", type=str)
@click.option(
    "--undelete",
    help="If set to True, the folder will be undeleted (i.e. the `deleted` mark will be removed)",
    is_flag=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, folder_id, undelete=False):
    """Marks the folder with the given ``id`` as `deleted` (or removes the `deleted` mark if the `undelete` param is True).

Output:

    
    """
    return ctx.gi.folders.delete_folder(folder_id, undelete=undelete)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('show_dataset')
@click.argument("library_id", type=str)
@click.argument("dataset_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, library_id, dataset_id):
    """Get details about a given library dataset. The required ``library_id`` can be obtained from the datasets's library content details.

Output:

    A dictionary containing information about the dataset in the
          library
    """
    return ctx.gi.libraries.show_dataset(library_id, dataset_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('show_group')
@click.argument("group_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, group_id):
    """Get details of a given group.

Output:

    A description of group
          For example::

            {'id': '33abac023ff186c2',
             'model_class': 'Group',
             'name': 'Listeria',
             'roles_url': '/api/groups/33abac023ff186c2/roles',
             'url': '/api/groups/33abac023ff186c2',
             'users_url': '/api/groups/33abac023ff186c2/users'}
    """
    return ctx.gi.groups.show_group(group_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('show_dataset_provenance')
@click.argument("history_id", type=str)
@click.argument("dataset_id", type=str)
@click.option(
    "--follow",
    help="If ``follow`` is ``True``, recursively fetch dataset provenance information for all inputs and their inputs, etc...",
    is_flag=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, history_id, dataset_id, follow=False):
    """Get details related to how dataset was created (``id``, ``job_id``, ``tool_id``, ``stdout``, ``stderr``, ``parameters``, ``inputs``, etc...).

Output:

    
    """
    return ctx.gi.histories.show_dataset_provenance(history_id, dataset_id, follow=follow)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('search_repositories')
@click.argument("q", type=str)
@click.option(
    "--page",
    help="page requested",
    default="1",
    show_default=True,
    type=int
)
@click.option(
    "--page_size",
    help="page size requested",
    default="10",
    show_default=True,
    type=int
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, q, page=1, page_size=10):
    """Search for repositories in a Galaxy Tool Shed.

Output:

    dictionary containing search hits as well as metadata for the
          search.
          For example::

            {u'hits': [{u'matched_terms': [],
               u'repository': {u'approved': u'no',
                u'description': u'Convert export file to fastq',
                u'full_last_updated': u'2015-01-18 09:48 AM',
                u'homepage_url': u'',
                u'id': u'bdfa208f0cf6504e',
                u'last_updated': u'less than a year',
                u'long_description': u'This is a simple too to convert Solexas Export files to FASTQ files.',
                u'name': u'export_to_fastq',
                u'remote_repository_url': u'',
                u'repo_owner_username': u'louise',
                u'times_downloaded': 164},
               u'score': 4.92},
              {u'matched_terms': [],
               u'repository': {u'approved': u'no',
                u'description': u'Convert BAM file to fastq',
                u'full_last_updated': u'2015-04-07 11:57 AM',
                u'homepage_url': u'',
                u'id': u'175812cd7caaf439',
                u'last_updated': u'less than a month',
                u'long_description': u'Use Picards SamToFastq to convert a BAM file to fastq. Useful for storing reads as BAM in Galaxy and converting to fastq when needed for analysis.',
                u'name': u'bam_to_fastq',
                u'remote_repository_url': u'',
                u'repo_owner_username': u'brad-chapman',
                u'times_downloaded': 138},
               u'score': 4.14}],
             u'hostname': u'https://testtoolshed.g2.bx.psu.edu/',
             u'page': u'1',
             u'page_size': u'2',
             u'total_results': u'64'}
    """
    return ctx.gi.repositories.search_repositories(q, page=page, page_size=page_size)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('run_workflow')
@click.argument("workflow_id", type=str)
@click.option(
    "--dataset_map",
    help="A mapping of workflow inputs to datasets. The datasets source can be a LibraryDatasetDatasetAssociation (``ldda``), LibraryDataset (``ld``), or HistoryDatasetAssociation (``hda``). The map must be in the following format: ``{'<input>': {'id': <encoded dataset ID>, 'src': '[ldda, ld, hda]'}}`` (e.g. ``{'23': {'id': '29beef4fadeed09f', 'src': 'ld'}}``)",
    type=str
)
@click.option(
    "--params",
    help="A mapping of non-datasets tool parameters (see below)",
    type=str
)
@click.option(
    "--history_id",
    help="The encoded history ID where to store the workflow output. Alternatively, ``history_name`` may be specified to create a new history.",
    type=str
)
@click.option(
    "--history_name",
    help="Create a new history with the given name to store the workflow output. If both ``history_id`` and ``history_name`` are provided, ``history_name`` is ignored. If neither is specified, a new 'Unnamed history' is created.",
    type=str
)
@click.option(
    "--import_inputs_to_history",
    help="If ``True``, used workflow inputs will be imported into the history. If ``False``, only workflow outputs will be visible in the given history.",
    is_flag=True
)
@click.option(
    "--replacement_params",
    help="pattern-based replacements for post-job actions (see below)",
    type=str
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, workflow_id, dataset_map="", params="", history_id="", history_name="", import_inputs_to_history=False, replacement_params=""):
    """Run the workflow identified by ``workflow_id``.

Output:

    A dict containing the history ID where the outputs are placed
          as well as output dataset IDs. For example::

            {u'history': u'64177123325c9cfd',
             u'outputs': [u'aa4d3084af404259']}

        The ``params`` dict should be specified as follows::

          {STEP_ID: PARAM_DICT, ...}

        where PARAM_DICT is::

          {PARAM_NAME: VALUE, ...}

        For backwards compatibility, the following (deprecated) format is
        also supported for ``params``::

          {TOOL_ID: PARAM_DICT, ...}

        in which case PARAM_DICT affects all steps with the given tool id.
        If both by-tool-id and by-step-id specifications are used, the
        latter takes precedence.

        Finally (again, for backwards compatibility), PARAM_DICT can also
        be specified as::

          {'param': PARAM_NAME, 'value': VALUE}

        Note that this format allows only one parameter to be set per step.

        The ``replacement_params`` dict should map parameter names in
        post-job actions (PJAs) to their runtime values. For
        instance, if the final step has a PJA like the following::

          {u'RenameDatasetActionout_file1': {u'action_arguments': {u'newname': u'${output}'},
            u'action_type': u'RenameDatasetAction',
            u'output_name': u'out_file1'}}

        then the following renames the output dataset to 'foo'::

          replacement_params = {'output': 'foo'}

        see also `this email thread
        <http://lists.bx.psu.edu/pipermail/galaxy-dev/2011-September/006875.html>`_.

        .. warning::
            This method waits for the whole workflow to be scheduled before
            returning and does not scale to large workflows as a result. This
            method has therefore been deprecated in favor of
            :meth:`invoke_workflow`, which also features improved default
            behavior for dataset input handling.
    """
    return ctx.gi.workflows.run_workflow(workflow_id, dataset_map=dataset_map, params=params, history_id=history_id, history_name=history_name, import_inputs_to_history=import_inputs_to_history, replacement_params=replacement_params)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('get_ftp_files')
@click.option(
    "--deleted",
    help=""
)
@pass_context
@custom_exception
@list_output
def cli(ctx, deleted=False):
    """Get a list of local files.

Output:

    A list of dicts with details on individual files on FTP
    """
    return ctx.gi.ftpfiles.get_ftp_files(deleted=deleted)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('get_ordered_installable_revisions')
@click.argument("name", type=str)
@click.argument("owner", type=str)
@pass_context
@custom_exception
@list_output
def cli(ctx, name, owner):
    """Returns the ordered list of changeset revision hash strings that are associated with installable revisions. As in the changelog, the list is ordered oldest to newest.

Output:

    List of changeset revision hash strings from oldest to newest
    """
    return ctx.gi.repositories.get_ordered_installable_revisions(name, owner)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('get_categories')
@click.option(
    "--deleted",
    help="whether to show deleted categories",
    is_flag=True
)
@pass_context
@custom_exception
@list_output
def cli(ctx, deleted=False):
    """Returns a list of dictionaries that contain descriptions of the repository categories found on the given Tool Shed instance.

Output:

    A list of dictionaries containing information about
          repository categories present in the Tool Shed.
          For example::

            [{u'deleted': False,
              u'description': u'Tools for manipulating data',
              u'id': u'175812cd7caaf439',
              u'model_class': u'Category',
              u'name': u'Text Manipulation',
              u'url': u'/api/categories/175812cd7caaf439'}]

        .. versionadded:: 0.5.2
    """
    return ctx.gi.categories.get_categories(deleted=deleted)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('cancel_invocation')
@click.argument("workflow_id", type=str)
@click.argument("invocation_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, workflow_id, invocation_id):
    """Cancel the scheduling of a workflow.

Output:

    
    """
    return ctx.gi.workflows.cancel_invocation(workflow_id, invocation_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('get_workflow_inputs')
@click.argument("workflow_id", type=str)
@click.argument("label", type=str)
@pass_context
@custom_exception
@list_output
def cli(ctx, workflow_id, label):
    """Get a list of workflow input IDs that match the given label. If no input matches the given label, an empty list is returned.

Output:

    list of workflow inputs matching the label query
    """
    return ctx.gi.workflows.get_workflow_inputs(workflow_id, label)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('show_folder')
@click.argument("folder_id", type=str)
@click.option(
    "--contents",
    help="True to get the contents of the folder, rather than just the folder details.",
    is_flag=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, folder_id, contents=False):
    """Display information about a folder.

Output:

    dictionary including details of the folder
    """
    return ctx.gi.folders.show_folder(folder_id, contents=contents)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('import_workflow_from_local_path')
@click.argument("file_local_path", type=str)
@click.option(
    "--publish",
    help="if ``True`` the uploaded workflow will be published; otherwise it will be visible only by the user which uploads it (default)",
    is_flag=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, file_local_path, publish=False):
    """Imports a new workflow given the path to a file containing a previously exported workflow.

Output:

    
    """
    return ctx.gi.workflows.import_workflow_from_local_path(file_local_path, publish=publish)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('delete_library_dataset')
@click.argument("library_id", type=str)
@click.argument("dataset_id", type=str)
@click.option(
    "--purged",
    help="Indicate that the dataset should be purged (permanently deleted)",
    is_flag=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, library_id, dataset_id, purged=False):
    """Delete a library dataset in a data library.

Output:

    A dictionary containing the dataset id and whether the dataset
          has been deleted.
          For example::

            {u'deleted': True,
             u'id': u'60e680a037f41974'}
    """
    return ctx.gi.libraries.delete_library_dataset(library_id, dataset_id, purged=purged)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('show_visualization')
@click.argument("visual_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, visual_id):
    """Get details of a given visualization.

Output:

    A description of the given visualization.
          For example::

            {u'annotation': None,
             u'dbkey': u'mm9',
             u'id': u'18df9134ea75e49c',
             u'latest_revision': {  ... },
             u'model_class': u'Visualization',
             u'revisions': [u'aa90649bb3ec7dcb', u'20622bc6249c0c71'],
             u'slug': u'visualization-for-grant-1',
             u'title': u'Visualization For Grant',
             u'type': u'trackster',
             u'url': u'/u/azaron/v/visualization-for-grant-1',
             u'user_id': u'21e4aed91386ca8b'}
    """
    return ctx.gi.visual.show_visualization(visual_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('install_dependencies')
@click.argument("tool_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, tool_id):
    """Install dependencies for a given tool via a resolver. This works only for Conda currently. This functionality is available since Galaxy release_16.10 and is available only to Galaxy admins.

Output:

    
    """
    return ctx.gi.tools.install_dependencies(tool_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('get_genomes')
@pass_context
@custom_exception
@dict_output
def cli(ctx):
    """Returns a list of installed genomes

Output:

    
    """
    return ctx.gi.genomes.get_genomes()



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('export_workflow_json')
@click.argument("workflow_id")
@pass_context
@custom_exception
@dict_output
def cli(ctx, workflow_id):
    """.. deprecated:: 0.9.0 Use :meth:`export_workflow_dict` instead.

Output:

    
    """
    return ctx.gi.workflows.export_workflow_json(workflow_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('update_folder')
@click.argument("folder_id", type=str)
@click.argument("name", type=str)
@click.option(
    "--description",
    help="folder's description",
    type=str
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, folder_id, name, description=""):
    """Update folder information.

Output:

    details of the updated folder
    """
    return ctx.gi.folders.update_folder(folder_id, name, description=description)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('upload_file_from_local_path')
@click.argument("library_id", type=str)
@click.argument("file_local_path", type=str)
@click.option(
    "--folder_id",
    help="id of the folder where to place the uploaded file. If not provided, the root folder will be used",
    type=str
)
@click.option(
    "--file_type",
    help="Galaxy file format name",
    default="auto",
    show_default=True,
    type=str
)
@click.option(
    "--dbkey",
    help="Dbkey",
    default="?",
    show_default=True,
    type=str
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, library_id, file_local_path, folder_id="", file_type="auto", dbkey="?"):
    """Read local file contents from file_local_path and upload data to a library.

Output:

    
    """
    return ctx.gi.libraries.upload_file_from_local_path(library_id, file_local_path, folder_id=folder_id, file_type=file_type, dbkey=dbkey)



import click
from parsec.commands.histories.create_dataset_collection import cli as func0
from parsec.commands.histories.create_history import cli as func1
from parsec.commands.histories.create_history_tag import cli as func2
from parsec.commands.histories.delete_dataset import cli as func3
from parsec.commands.histories.delete_dataset_collection import cli as func4
from parsec.commands.histories.delete_history import cli as func5
from parsec.commands.histories.download_dataset import cli as func6
from parsec.commands.histories.download_history import cli as func7
from parsec.commands.histories.export_history import cli as func8
from parsec.commands.histories.get_current_history import cli as func9
from parsec.commands.histories.get_histories import cli as func10
from parsec.commands.histories.get_most_recently_used_history import cli as func11
from parsec.commands.histories.get_status import cli as func12
from parsec.commands.histories.show_dataset import cli as func13
from parsec.commands.histories.show_dataset_collection import cli as func14
from parsec.commands.histories.show_dataset_provenance import cli as func15
from parsec.commands.histories.show_history import cli as func16
from parsec.commands.histories.show_matching_datasets import cli as func17
from parsec.commands.histories.undelete_history import cli as func18
from parsec.commands.histories.update_dataset import cli as func19
from parsec.commands.histories.update_dataset_collection import cli as func20
from parsec.commands.histories.update_history import cli as func21
from parsec.commands.histories.upload_dataset_from_library import cli as func22


@click.group()
def cli():
    pass


cli.add_command(func0)
cli.add_command(func1)
cli.add_command(func2)
cli.add_command(func3)
cli.add_command(func4)
cli.add_command(func5)
cli.add_command(func6)
cli.add_command(func7)
cli.add_command(func8)
cli.add_command(func9)
cli.add_command(func10)
cli.add_command(func11)
cli.add_command(func12)
cli.add_command(func13)
cli.add_command(func14)
cli.add_command(func15)
cli.add_command(func16)
cli.add_command(func17)
cli.add_command(func18)
cli.add_command(func19)
cli.add_command(func20)
cli.add_command(func21)
cli.add_command(func22)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('get_version')
@pass_context
@custom_exception
@dict_output
def cli(ctx):
    """Get the current version of the Galaxy instance. This functionality is available since Galaxy ``release_15.03``.

Output:

    Version of the Galaxy instance

        For example::

            {'extra': {}, 'version_major': '17.01'}
    """
    return ctx.gi.config.get_version()



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('get_folders')
@click.argument("library_id")
@click.option(
    "--folder_id",
    help="filter for folder by folder id",
    type=str
)
@click.option(
    "--name",
    help="filter for folder by name. For ``name`` specify the full path of the folder starting from the library's root folder, e.g. ``/subfolder/subsubfolder``.",
    type=str
)
@pass_context
@custom_exception
@list_output
def cli(ctx, library_id, folder_id="", name=""):
    """Get all the folders or filter specific one(s) via the provided ``name`` or ``folder_id`` in data library with id ``library_id``. Provide only one argument: ``name`` or ``folder_id``, but not both.

Output:

    list of dicts each containing basic information about a folder
    """
    return ctx.gi.libraries.get_folders(library_id, folder_id=folder_id, name=name)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('show_job')
@click.argument("job_id", type=str)
@click.option(
    "--full_details",
    help="when ``True``, the complete list of details for the given job.",
    is_flag=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, job_id, full_details=False):
    """Get details of a given job of the current user.

Output:

    A description of the given job.
          For example::

            {u'create_time': u'2014-03-01T16:17:29.828624',
             u'exit_code': 0,
             u'id': u'a799d38679e985db',
             u'inputs': {u'input': {u'id': u'ebfb8f50c6abde6d',
               u'src': u'hda'}},
             u'model_class': u'Job',
             u'outputs': {u'output': {u'id': u'a799d38679e985db',
               u'src': u'hda'}},
             u'params': {u'chromInfo': u'"/opt/galaxy-central/tool-data/shared/ucsc/chrom/?.len"',
               u'dbkey': u'"?"',
               u'seq_col': u'"2"',
               u'title_col': u'["1"]'},
             u'state': u'ok',
             u'tool_id': u'tab2fasta',
             u'update_time': u'2014-03-01T16:17:31.930728'}
    """
    return ctx.gi.jobs.show_job(job_id, full_details=full_details)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('get_visualizations')
@pass_context
@custom_exception
@list_output
def cli(ctx):
    """Get the list of all visualizations.

Output:

    A list of dicts with details on individual visualizations.
          For example::

            [{u'dbkey': u'eschColi_K12',
              u'id': u'df1c7c96fc427c2d',
              u'title': u'AVTest1',
              u'type': u'trackster',
              u'url': u'/api/visualizations/df1c7c96fc427c2d'},
             {u'dbkey': u'mm9',
              u'id': u'a669f50f8bf55b02',
              u'title': u'Bam to Bigwig',
              u'type': u'trackster',
              u'url': u'/api/visualizations/a669f50f8bf55b02'}]
    """
    return ctx.gi.visual.get_visualizations()



import click
from parsec.commands.toolshed_repositories.create_repository import cli as func0
from parsec.commands.toolshed_repositories.get_ordered_installable_revisions import cli as func1
from parsec.commands.toolshed_repositories.get_repositories import cli as func2
from parsec.commands.toolshed_repositories.get_repository_revision_install_info import cli as func3
from parsec.commands.toolshed_repositories.repository_revisions import cli as func4
from parsec.commands.toolshed_repositories.search_repositories import cli as func5
from parsec.commands.toolshed_repositories.show_repository import cli as func6
from parsec.commands.toolshed_repositories.show_repository_revision import cli as func7
from parsec.commands.toolshed_repositories.update_repository import cli as func8


@click.group()
def cli():
    pass


cli.add_command(func0)
cli.add_command(func1)
cli.add_command(func2)
cli.add_command(func3)
cli.add_command(func4)
cli.add_command(func5)
cli.add_command(func6)
cli.add_command(func7)
cli.add_command(func8)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('create_form')
@click.argument("form_xml_text", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, form_xml_text):
    """Create a new form.

Output:

    
    """
    return ctx.gi.forms.create_form(form_xml_text)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('create_library')
@click.argument("name", type=str)
@click.option(
    "--description",
    help="Optional data library description",
    type=str
)
@click.option(
    "--synopsis",
    help="Optional data library synopsis",
    type=str
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, name, description="", synopsis=""):
    """Create a data library with the properties defined in the arguments.

Output:

    Details of the created library.
          For example::

            {'id': 'f740ab636b360a70',
             'name': 'Library from bioblend',
             'url': '/api/libraries/f740ab636b360a70'}
    """
    return ctx.gi.libraries.create_library(name, description=description, synopsis=synopsis)



import click
from parsec.commands.tool_data.delete_data_table import cli as func0
from parsec.commands.tool_data.get_data_tables import cli as func1
from parsec.commands.tool_data.reload_data_table import cli as func2
from parsec.commands.tool_data.show_data_table import cli as func3


@click.group()
def cli():
    pass


cli.add_command(func0)
cli.add_command(func1)
cli.add_command(func2)
cli.add_command(func3)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('get_datatypes')
@click.option(
    "--extension_only",
    help=""
)
@click.option(
    "--upload_only",
    help=""
)
@pass_context
@custom_exception
@list_output
def cli(ctx, extension_only=False, upload_only=False):
    """Get the list of all installed datatypes.

Output:

    A list of datatype names.
          For example::

            [u'snpmatrix',
             u'snptest',
             u'tabular',
             u'taxonomy',
             u'twobit',
             u'txt',
             u'vcf',
             u'wig',
             u'xgmml',
             u'xml']
    """
    return ctx.gi.datatypes.get_datatypes(extension_only=extension_only, upload_only=upload_only)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('paste_content')
@click.argument("content", type=str)
@click.argument("history_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, content, history_id):
    """Upload a string to a new dataset in the history specified by ``history_id``.

Output:

    
    """
    return ctx.gi.tools.paste_content(content, history_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('get_libraries')
@click.option(
    "--library_id",
    help="filter for library by library id",
    type=str
)
@click.option(
    "--name",
    help="If ``name`` is set and multiple names match the given name, all the libraries matching the argument will be returned",
    type=str
)
@click.option(
    "--deleted",
    help="If set to ``True``, return libraries that have been deleted",
    is_flag=True
)
@pass_context
@custom_exception
@list_output
def cli(ctx, library_id="", name="", deleted=False):
    """Get all the libraries or filter for specific one(s) via the provided name or ID. Provide only one argument: ``name`` or ``library_id``, but not both.

Output:

    list of dicts each containing basic information about a library
    """
    return ctx.gi.libraries.get_libraries(library_id=library_id, name=name, deleted=deleted)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('show_repository')
@click.argument("toolShed_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, toolShed_id):
    """Display information of a repository from Tool Shed

Output:

    Information about the tool.
          For example::

            {u'category_ids': [u'c1df3132f6334b0e', u'f6d7b0037d901d9b'],
             u'deleted': False,
             u'deprecated': False,
             u'description': u'Order Contigs',
             u'homepage_url': u'',
             u'id': u'287bd69f724b99ce',
             u'long_description': u'',
             u'name': u'best_tool_ever',
             u'owner': u'billybob',
             u'private': False,
             u'remote_repository_url': u'',
             u'times_downloaded': 0,
             u'type': u'unrestricted',
             u'url': u'/api/repositories/287bd69f724b99ce',
             u'user_id': u'5cefd48bc04af6d4'}

        .. versionchanged:: 0.4.1
          Changed method name from ``show_tool`` to ``show_repository`` to
          better align with the Tool Shed concepts.
    """
    return ctx.gi.repositories.show_repository(toolShed_id)



import click
from parsec.commands.quotas.create_quota import cli as func0
from parsec.commands.quotas.delete_quota import cli as func1
from parsec.commands.quotas.get_quotas import cli as func2
from parsec.commands.quotas.show_quota import cli as func3
from parsec.commands.quotas.undelete_quota import cli as func4
from parsec.commands.quotas.update_quota import cli as func5


@click.group()
def cli():
    pass


cli.add_command(func0)
cli.add_command(func1)
cli.add_command(func2)
cli.add_command(func3)
cli.add_command(func4)
cli.add_command(func5)



import click
from parsec.commands.users.create_local_user import cli as func0
from parsec.commands.users.create_remote_user import cli as func1
from parsec.commands.users.create_user_apikey import cli as func2
from parsec.commands.users.delete_user import cli as func3
from parsec.commands.users.get_current_user import cli as func4
from parsec.commands.users.get_user_apikey import cli as func5
from parsec.commands.users.get_users import cli as func6
from parsec.commands.users.show_user import cli as func7


@click.group()
def cli():
    pass


cli.add_command(func0)
cli.add_command(func1)
cli.add_command(func2)
cli.add_command(func3)
cli.add_command(func4)
cli.add_command(func5)
cli.add_command(func6)
cli.add_command(func7)



import click
from parsec.commands.datasets.download_dataset import cli as func0
from parsec.commands.datasets.show_dataset import cli as func1


@click.group()
def cli():
    pass


cli.add_command(func0)
cli.add_command(func1)



from __future__ import absolute_import
import os
from bioblend import galaxy, toolshed
from .config import read_global_config, global_config_path


def get_instance(instance_name=None):
    # I don't like reading the config twice.
    conf = read_global_config()
    if not os.path.exists(global_config_path()):
        # Probably creating the file for the first time.
        return None

    if instance_name is None or instance_name == '__default':
        try:
            instance_name = conf['__default']
        except KeyError:
            raise Exception("Unknown Galaxy instance and no __default provided")

    if instance_name not in conf:
        raise Exception("Unknown Galaxy instance; check spelling or add to ~/.planemo.yml")

    return conf[instance_name]


def get_galaxy_instance(instance_name=None):
    conf = get_instance(instance_name=instance_name)
    return galaxy.GalaxyInstance(conf['url'],
                                 conf['key'])


def get_toolshed_instance(instance_name=None):
    conf = get_instance(instance_name=instance_name)
    return toolshed.ToolShedInstance(conf['url'],
                                     conf['key'])



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('create_local_user')
@click.argument("username", type=str)
@click.argument("user_email", type=str)
@click.argument("password", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, username, user_email, password):
    """Create a new Galaxy local user.

Output:

    a dictionary containing information about the created user
    """
    return ctx.gi.users.create_local_user(username, user_email, password)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('update_dataset_collection')
@click.argument("history_id", type=str)
@click.argument("dataset_collection_id", type=str)
@click.option(
    "--deleted",
    help="Mark or unmark history dataset collection as deleted",
    is_flag=True
)
@click.option(
    "--name",
    help="Replace history dataset collection name with the given string",
    type=str
)
@click.option(
    "--visible",
    help="Mark or unmark history dataset collection as visible",
    is_flag=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, history_id, dataset_collection_id, deleted=None, name=None, visible=None):
    """Update history dataset collection metadata. Some of the attributes that can be modified are documented below.

Output:

    the updated dataset collection attributes

        .. warning::
            The return value was changed in BioBlend v0.8.0, previously it was
            the status code (type int).
    """
    kwargs = {}
    if deleted is not None:
        kwargs['deleted'] = deleted
    if name and len(name) > 0:
        kwargs['name'] = name
    if visible is not None:
        kwargs['visible'] = visible

    return ctx.gi.histories.update_dataset_collection(history_id, dataset_collection_id, **kwargs)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('upload_from_ftp')
@click.argument("path", type=str)
@click.argument("history_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, path, history_id):
    """Upload the file specified by ``path`` from the user's FTP directory to the history specified by ``history_id``.

Output:

    
    """
    return ctx.gi.tools.upload_from_ftp(path, history_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('get_histories')
@click.option(
    "--history_id",
    help="Encoded history ID to filter on",
    type=str
)
@click.option(
    "--name",
    help="Name of history to filter on",
    type=str
)
@click.option(
    "--deleted",
    help=""
)
@pass_context
@custom_exception
@list_output
def cli(ctx, history_id="", name="", deleted=False):
    """Get all histories or filter the specific one(s) via the provided ``name`` or ``history_id``. Provide only one argument, ``name`` or ``history_id``, but not both.

Output:

    Return a list of history element dicts. If more than one
                 history matches the given ``name``, return the list of all the
                 histories with the given name
    """
    return ctx.gi.histories.get_histories(history_id=history_id, name=name, deleted=deleted)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, str_output


@click.command('export_history')
@click.argument("history_id", type=str)
@click.option(
    "--gzip",
    help="create .tar.gz archive if ``True``, else .tar",
    default="True",
    show_default=True,
    is_flag=True
)
@click.option(
    "--include_hidden",
    help="whether to include hidden datasets in the export",
    is_flag=True
)
@click.option(
    "--include_deleted",
    help="whether to include deleted datasets in the export",
    is_flag=True
)
@click.option(
    "--wait",
    help="if ``True``, block until the export is ready; else, return immediately",
    is_flag=True
)
@pass_context
@custom_exception
@str_output
def cli(ctx, history_id, gzip=True, include_hidden=False, include_deleted=False, wait=False):
    """Start a job to create an export archive for the given history.

Output:

    ``jeha_id`` of the export, or empty if ``wait`` is ``False``
          and the export is not ready.
    """
    return ctx.gi.histories.export_history(history_id, gzip=gzip, include_hidden=include_hidden, include_deleted=include_deleted, wait=wait)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('run_invocation_step_action')
@click.argument("workflow_id", type=str)
@click.argument("invocation_id", type=str)
@click.argument("step_id", type=str)
@click.argument("action")
@pass_context
@custom_exception
@dict_output
def cli(ctx, workflow_id, invocation_id, step_id, action):
    """nature of this action and what is expected will vary based on the the type of workflow step (the only currently valid action is True/False for pause steps).

Output:

    
    """
    return ctx.gi.workflows.run_invocation_step_action(workflow_id, invocation_id, step_id, action)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('get_current_user')
@pass_context
@custom_exception
@dict_output
def cli(ctx):
    """Display information about the user associated with this Galaxy connection.

Output:

    a dictionary containing information about the current user
    """
    return ctx.gi.users.get_current_user()



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('show_tool')
@click.argument("tool_id", type=str)
@click.option(
    "--io_details",
    help="if True, get also input and output details",
    is_flag=True
)
@click.option(
    "--link_details",
    help="if True, get also link details",
    is_flag=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, tool_id, io_details=False, link_details=False):
    """Get details of a given tool.

Output:

    
    """
    return ctx.gi.tools.show_tool(tool_id, io_details=io_details, link_details=link_details)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('search_tools')
@click.argument("q", type=str)
@click.option(
    "--page",
    help="page requested",
    default="1",
    show_default=True,
    type=int
)
@click.option(
    "--page_size",
    help="page size requested",
    default="10",
    show_default=True,
    type=int
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, q, page=1, page_size=10):
    """Search for tools in a Galaxy Tool Shed.

Output:

    dictionary containing search hits as well as metadata for the
          search. For example::

            {u'hits': [{u'matched_terms': [],
               u'score': 3.0,
               u'tool': {u'description': u'convert between various FASTQ quality formats',
                u'id': u'69819b84d55f521efda001e0926e7233',
                u'name': u'FASTQ Groomer',
                u'repo_name': None,
                u'repo_owner_username': u'devteam'}},
              {u'matched_terms': [],
               u'score': 3.0,
               u'tool': {u'description': u'converts a bam file to fastq files.',
                u'id': u'521e282770fd94537daff87adad2551b',
                u'name': u'Defuse BamFastq',
                u'repo_name': None,
                u'repo_owner_username': u'jjohnson'}}],
             u'hostname': u'https://testtoolshed.g2.bx.psu.edu/',
             u'page': u'1',
             u'page_size': u'2',
             u'total_results': u'118'}
    """
    return ctx.gi.tools.search_tools(q, page=page, page_size=page_size)



import click
from parsec.commands.libraries.copy_from_dataset import cli as func0
from parsec.commands.libraries.create_folder import cli as func1
from parsec.commands.libraries.create_library import cli as func2
from parsec.commands.libraries.delete_library import cli as func3
from parsec.commands.libraries.delete_library_dataset import cli as func4
from parsec.commands.libraries.get_folders import cli as func5
from parsec.commands.libraries.get_libraries import cli as func6
from parsec.commands.libraries.get_library_permissions import cli as func7
from parsec.commands.libraries.set_library_permissions import cli as func8
from parsec.commands.libraries.show_dataset import cli as func9
from parsec.commands.libraries.show_folder import cli as func10
from parsec.commands.libraries.show_library import cli as func11
from parsec.commands.libraries.update_library_dataset import cli as func12
from parsec.commands.libraries.upload_file_contents import cli as func13
from parsec.commands.libraries.upload_file_from_local_path import cli as func14
from parsec.commands.libraries.upload_file_from_server import cli as func15
from parsec.commands.libraries.upload_file_from_url import cli as func16
from parsec.commands.libraries.upload_from_galaxy_filesystem import cli as func17
from parsec.commands.libraries.wait_for_dataset import cli as func18


@click.group()
def cli():
    pass


cli.add_command(func0)
cli.add_command(func1)
cli.add_command(func2)
cli.add_command(func3)
cli.add_command(func4)
cli.add_command(func5)
cli.add_command(func6)
cli.add_command(func7)
cli.add_command(func8)
cli.add_command(func9)
cli.add_command(func10)
cli.add_command(func11)
cli.add_command(func12)
cli.add_command(func13)
cli.add_command(func14)
cli.add_command(func15)
cli.add_command(func16)
cli.add_command(func17)
cli.add_command(func18)



import click
from parsec.commands.tools.get_tool_panel import cli as func0
from parsec.commands.tools.get_tools import cli as func1
from parsec.commands.tools.install_dependencies import cli as func2
from parsec.commands.tools.paste_content import cli as func3
from parsec.commands.tools.put_url import cli as func4
from parsec.commands.tools.run_tool import cli as func5
from parsec.commands.tools.show_tool import cli as func6
from parsec.commands.tools.upload_file import cli as func7
from parsec.commands.tools.upload_from_ftp import cli as func8


@click.group()
def cli():
    pass


cli.add_command(func0)
cli.add_command(func1)
cli.add_command(func2)
cli.add_command(func3)
cli.add_command(func4)
cli.add_command(func5)
cli.add_command(func6)
cli.add_command(func7)
cli.add_command(func8)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('show_repository_revision')
@click.argument("metadata_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, metadata_id):
    """Returns a dictionary that includes information about a specified repository revision.

Output:

    Returns a dictionary that includes information about a
          specified repository revision.
          For example::

            {u'changeset_revision': u'7602de1e7f32',
             u'do_not_test': False,
             u'downloadable': True,
             u'has_repository_dependencies': False,
             u'id': u'504be8aaa652c154',
             u'includes_datatypes': False,
             u'includes_tool_dependencies': False,
             u'includes_tools': True,
             u'includes_tools_for_display_in_tool_panel': True,
             u'includes_workflows': False,
             u'malicious': False,
             u'missing_test_components': True,
             u'repository_id': u'491b7a3fddf9366f',
             u'test_install_error': False,
             u'time_last_tested': None,
             u'tool_test_results': {u'missing_test_components': []},
             u'tools_functionally_correct': False,
             u'url': u'/api/repository_revisions/504be8aaa652c154'}
    """
    return ctx.gi.repositories.show_repository_revision(metadata_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('add_group_user')
@click.argument("group_id", type=str)
@click.argument("user_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, group_id, user_id):
    """Add a user to the given group.

Output:

    Added group user's info
    """
    return ctx.gi.groups.add_group_user(group_id, user_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('get_forms')
@pass_context
@custom_exception
@dict_output
def cli(ctx):
    """Get the list of all forms.

Output:

    
    """
    return ctx.gi.forms.get_forms()



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('show_genome')
@click.argument("id", type=str)
@click.option(
    "--num",
    help="num",
    type=str
)
@click.option(
    "--chrom",
    help="chrom",
    type=str
)
@click.option(
    "--low",
    help="low",
    type=str
)
@click.option(
    "--high",
    help="high",
    type=str
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, id, num="", chrom="", low="", high=""):
    """Returns information about build <id>

Output:

    
    """
    return ctx.gi.genomes.show_genome(id, num=num, chrom=chrom, low=low, high=high)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('get_invocations')
@click.argument("workflow_id", type=str)
@pass_context
@custom_exception
@list_output
def cli(ctx, workflow_id):
    """Get a list containing all the workflow invocations corresponding to the specified workflow.

Output:

    A list of workflow invocations.
          For example::

            [{u'history_id': u'2f94e8ae9edff68a',
              u'id': u'df7a1f0c02a5b08e',
              u'model_class': u'WorkflowInvocation',
              u'state': u'new',
              u'update_time': u'2015-10-31T22:00:22',
              u'uuid': u'c8aa2b1c-801a-11e5-a9e5-8ca98228593c',
              u'workflow_id': u'03501d7626bd192f'}]
    """
    return ctx.gi.workflows.get_invocations(workflow_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, str_output


@click.command('delete_quota')
@click.argument("quota_id", type=str)
@pass_context
@custom_exception
@str_output
def cli(ctx, quota_id):
    """Delete a quota

Output:

    A description of the changes, mentioning the deleted quota.
          For example::

            "Deleted 1 quotas: Testing-B"
    """
    return ctx.gi.quotas.delete_quota(quota_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('create_role')
@click.argument("role_name", type=str)
@click.argument("description", type=str)
@click.option(
    "--user_ids",
    help="A list of encoded user IDs to add to the new role",
    type=str,
    multiple=True
)
@click.option(
    "--group_ids",
    help="A list of encoded group IDs to add to the new role",
    type=str,
    multiple=True
)
@pass_context
@custom_exception
@list_output
def cli(ctx, role_name, description, user_ids=None, group_ids=None):
    """Create a new role.

Output:

    A (size 1) list with newly created role
          details, like::

            [{u'description': u'desc',
              u'url': u'/api/roles/ebfb8f50c6abde6d',
              u'model_class': u'Role',
              u'type': u'admin',
              u'id': u'ebfb8f50c6abde6d',
              u'name': u'Foo'}]
    """
    return ctx.gi.roles.create_role(role_name, description, user_ids=user_ids, group_ids=group_ids)



import click
from parsec.commands.forms.create_form import cli as func0
from parsec.commands.forms.get_forms import cli as func1
from parsec.commands.forms.show_form import cli as func2


@click.group()
def cli():
    pass


cli.add_command(func0)
cli.add_command(func1)
cli.add_command(func2)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('repository_revisions')
@click.option(
    "--downloadable",
    help="Can the tool be downloaded",
    is_flag=True
)
@click.option(
    "--malicious",
    help=""
)
@click.option(
    "--tools_functionally_correct",
    help=""
)
@click.option(
    "--missing_test_components",
    help=""
)
@click.option(
    "--do_not_test",
    help=""
)
@click.option(
    "--includes_tools",
    help=""
)
@click.option(
    "--test_install_error",
    help=""
)
@click.option(
    "--skip_tool_test",
    help=""
)
@pass_context
@custom_exception
@list_output
def cli(ctx, downloadable="", malicious="", tools_functionally_correct="", missing_test_components="", do_not_test="", includes_tools="", test_install_error="", skip_tool_test=""):
    """Returns a (possibly filtered) list of dictionaries that include information about all repository revisions. The following parameters can be used to filter the list.

Output:

    Returns a (possibly filtered) list of dictionaries that include
          information about all repository revisions.
          For example::

            [{u'changeset_revision': u'6e26c5a48e9a',
              u'do_not_test': False,
              u'downloadable': True,
              u'has_repository_dependencies': False,
              u'id': u'92250afff777a169',
              u'includes_datatypes': False,
              u'includes_tool_dependencies': False,
              u'includes_tools': True,
              u'includes_tools_for_display_in_tool_panel': True,
              u'includes_workflows': False,
              u'malicious': False,
              u'missing_test_components': False,
              u'repository_id': u'78f2604ff5e65707',
              u'test_install_error': False,
              u'time_last_tested': None,
              u'tools_functionally_correct': False,
              u'url': u'/api/repository_revisions/92250afff777a169'},
             {u'changeset_revision': u'15a54fa11ad7',
              u'do_not_test': False,
              u'downloadable': True,
              u'has_repository_dependencies': False,
              u'id': u'd3823c748ae2205d',
              u'includes_datatypes': False,
              u'includes_tool_dependencies': False,
              u'includes_tools': True,
              u'includes_tools_for_display_in_tool_panel': True,
              u'includes_workflows': False,
              u'malicious': False,
              u'missing_test_components': False,
              u'repository_id': u'f9662009da7bfce0',
              u'test_install_error': False,
              u'time_last_tested': None,
              u'tools_functionally_correct': False,
              u'url': u'/api/repository_revisions/d3823c748ae2205d'}]
    """
    return ctx.gi.repositories.repository_revisions(downloadable=downloadable, malicious=malicious, tools_functionally_correct=tools_functionally_correct, missing_test_components=missing_test_components, do_not_test=do_not_test, includes_tools=includes_tools, test_install_error=test_install_error, skip_tool_test=skip_tool_test)



import click
from parsec.commands.visual.get_visualizations import cli as func0
from parsec.commands.visual.show_visualization import cli as func1


@click.group()
def cli():
    pass


cli.add_command(func0)
cli.add_command(func1)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('get_quotas')
@click.option(
    "--deleted",
    help="Only return quota(s) that have been deleted",
    is_flag=True
)
@pass_context
@custom_exception
@list_output
def cli(ctx, deleted=False):
    """Get a list of quotas

Output:

    A list of dicts with details on individual quotas.
          For example::

            [{u'id': u'0604c8a56abe9a50',
              u'model_class': u'Quota',
              u'name': u'test ',
              u'url': u'/api/quotas/0604c8a56abe9a50'},
             {u'id': u'1ee267091d0190af',
              u'model_class': u'Quota',
              u'name': u'workshop',
              u'url': u'/api/quotas/1ee267091d0190af'}]
    """
    return ctx.gi.quotas.get_quotas(deleted=deleted)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('download_dataset')
@click.argument("dataset_id", type=str)
@click.option(
    "--file_path",
    help="If this argument is provided, the dataset will be streamed to disk at that path (should be a directory if use_default_filename=True). If the file_path argument is not provided, the dataset content is loaded into memory and returned by the method (Memory consumption may be heavy as the entire file will be in memory).",
    type=str
)
@click.option(
    "--use_default_filename",
    help="If this argument is True, the exported file will be saved as file_path/%s, where %s is the dataset name. If this argument is False, file_path is assumed to contain the full file path including the filename.",
    default="True",
    show_default=True,
    is_flag=True
)
@click.option(
    "--maxwait",
    help="Total time (in seconds) to wait for the dataset state to become terminal. If the dataset state is not terminal within this time, a ``DatasetTimeoutException`` will be thrown.",
    default="12000",
    show_default=True,
    type=float
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, dataset_id, file_path="", use_default_filename=True, maxwait=12000):
    """Download a dataset to file or in memory. If the dataset state is not 'ok', a ``DatasetStateException`` will be thrown.

Output:

    If a file_path argument is not provided, returns a dict containing the file_content.
                 Otherwise returns nothing.
    """
    return ctx.gi.datasets.download_dataset(dataset_id, file_path=file_path, use_default_filename=use_default_filename, maxwait=maxwait)



import click
from parsec.commands.genomes.get_genomes import cli as func0
from parsec.commands.genomes.install_genome import cli as func1
from parsec.commands.genomes.show_genome import cli as func2


@click.group()
def cli():
    pass


cli.add_command(func0)
cli.add_command(func1)
cli.add_command(func2)



import click
from parsec.commands.jobs.get_jobs import cli as func0
from parsec.commands.jobs.get_state import cli as func1
from parsec.commands.jobs.search_jobs import cli as func2
from parsec.commands.jobs.show_job import cli as func3


@click.group()
def cli():
    pass


cli.add_command(func0)
cli.add_command(func1)
cli.add_command(func2)
cli.add_command(func3)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('show_matching_datasets')
@click.argument("history_id", type=str)
@click.option(
    "--name_filter",
    help="Only datasets whose name matches the ``name_filter`` regular expression will be returned; use plain strings for exact matches and None to match all datasets in the history",
    type=str
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, history_id, name_filter=""):
    """Get dataset details for matching datasets within a history.

Output:

    
    """
    return ctx.gi.histories.show_matching_datasets(history_id, name_filter=name_filter)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('get_group_roles')
@click.argument("group_id", type=str)
@pass_context
@custom_exception
@list_output
def cli(ctx, group_id):
    """Get the list of roles associated to the given group.

Output:

    List of group roles' info
    """
    return ctx.gi.groups.get_group_roles(group_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('create_history')
@click.option(
    "--name",
    help="Optional name for new history",
    type=str
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, name=""):
    """Create a new history, optionally setting the ``name``.

Output:

    Dictionary containing information about newly created history
    """
    return ctx.gi.histories.create_history(name=name)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('create_folder')
@click.argument("library_id", type=str)
@click.argument("folder_name", type=str)
@click.option(
    "--description",
    help="description of the new folder in the data library",
    type=str
)
@click.option(
    "--base_folder_id",
    help="id of the folder where to create the new folder. If not provided, the root folder will be used",
    type=str
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, library_id, folder_name, description="", base_folder_id=""):
    """Create a folder in a library.

Output:

    
    """
    return ctx.gi.libraries.create_folder(library_id, folder_name, description=description, base_folder_id=base_folder_id)



import click
from parsec.commands.workflows.cancel_invocation import cli as func0
from parsec.commands.workflows.delete_workflow import cli as func1
from parsec.commands.workflows.export_workflow_dict import cli as func2
from parsec.commands.workflows.export_workflow_json import cli as func3
from parsec.commands.workflows.export_workflow_to_local_path import cli as func4
from parsec.commands.workflows.get_invocations import cli as func5
from parsec.commands.workflows.get_workflow_inputs import cli as func6
from parsec.commands.workflows.get_workflows import cli as func7
from parsec.commands.workflows.import_shared_workflow import cli as func8
from parsec.commands.workflows.import_workflow_dict import cli as func9
from parsec.commands.workflows.import_workflow_from_local_path import cli as func10
from parsec.commands.workflows.import_workflow_json import cli as func11
from parsec.commands.workflows.invoke_workflow import cli as func12
from parsec.commands.workflows.run_invocation_step_action import cli as func13
from parsec.commands.workflows.run_workflow import cli as func14
from parsec.commands.workflows.show_invocation import cli as func15
from parsec.commands.workflows.show_invocation_step import cli as func16
from parsec.commands.workflows.show_workflow import cli as func17


@click.group()
def cli():
    pass


cli.add_command(func0)
cli.add_command(func1)
cli.add_command(func2)
cli.add_command(func3)
cli.add_command(func4)
cli.add_command(func5)
cli.add_command(func6)
cli.add_command(func7)
cli.add_command(func8)
cli.add_command(func9)
cli.add_command(func10)
cli.add_command(func11)
cli.add_command(func12)
cli.add_command(func13)
cli.add_command(func14)
cli.add_command(func15)
cli.add_command(func16)
cli.add_command(func17)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('get_current_history')
@pass_context
@custom_exception
@dict_output
def cli(ctx):
    """.. deprecated:: 0.5.2 Use :meth:`get_most_recently_used_history` instead.

Output:

    
    """
    return ctx.gi.histories.get_current_history()



import click
from parsec.commands.toolshed_categories.get_categories import cli as func0
from parsec.commands.toolshed_categories.show_category import cli as func1


@click.group()
def cli():
    pass


cli.add_command(func0)
cli.add_command(func1)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('delete_user')
@click.argument("user_id", type=str)
@click.option(
    "--purge",
    help="if ``True``, also purge (permanently delete) the history",
    is_flag=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, user_id, purge=False):
    """Delete a user.

Output:

    a dictionary containing information about the deleted user
    """
    return ctx.gi.users.delete_user(user_id, purge=purge)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('create_group')
@click.argument("group_name", type=str)
@click.option(
    "--user_ids",
    help="A list of encoded user IDs to add to the new group",
    type=str,
    multiple=True
)
@click.option(
    "--role_ids",
    help="A list of encoded role IDs to add to the new group",
    type=str,
    multiple=True
)
@pass_context
@custom_exception
@list_output
def cli(ctx, group_name, user_ids=None, role_ids=None):
    """Create a new group.

Output:

    A (size 1) list with newly created group
          details, like::

            [{u'id': u'7c9636938c3e83bf',
              u'model_class': u'Group',
              u'name': u'My Group Name',
              u'url': u'/api/groups/7c9636938c3e83bf'}]
    """
    return ctx.gi.groups.create_group(group_name, user_ids=user_ids, role_ids=role_ids)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('show_quota')
@click.argument("quota_id", type=str)
@click.option(
    "--deleted",
    help="Search for quota in list of ones already marked as deleted",
    is_flag=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, quota_id, deleted=False):
    """Display information on a quota

Output:

    A description of quota.
          For example::

            {u'bytes': 107374182400,
             u'default': [],
             u'description': u'just testing',
             u'display_amount': u'100.0 GB',
             u'groups': [],
             u'id': u'0604c8a56abe9a50',
             u'model_class': u'Quota',
             u'name': u'test ',
             u'operation': u'=',
             u'users': []}
    """
    return ctx.gi.quotas.show_quota(quota_id, deleted=deleted)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('create_quota')
@click.argument("name", type=str)
@click.argument("description", type=str)
@click.argument("amount", type=str)
@click.argument("operation", type=str)
@click.option(
    "--default",
    help="Whether or not this is a default quota. Valid values are ``no``, ``unregistered``, ``registered``. None is equivalent to ``no``.",
    default="no",
    show_default=True,
    type=str
)
@click.option(
    "--in_users",
    help="A list of user IDs or user emails.",
    type=str,
    multiple=True
)
@click.option(
    "--in_groups",
    help="A list of group IDs or names.",
    type=str,
    multiple=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, name, description, amount, operation, default="no", in_users=None, in_groups=None):
    """Create a new quota

Output:

    A description of quota.
          For example::

            {u'url': '/galaxy/api/quotas/386f14984287a0f7',
             u'model_class': 'Quota',
             u'message': "Quota 'Testing' has been created with 1 associated users and 0 associated groups.",
             u'id': '386f14984287a0f7',
             u'name': 'Testing'}
    """
    return ctx.gi.quotas.create_quota(name, description, amount, operation, default=default, in_users=in_users, in_groups=in_groups)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('export_workflow_to_local_path')
@click.argument("workflow_id", type=str)
@click.argument("file_local_path", type=str)
@click.option(
    "--use_default_filename",
    help="If the use_default_name parameter is True, the exported file will be saved as file_local_path/Galaxy-Workflow-%s.ga, where %s is the workflow name. If use_default_name is False, file_local_path is assumed to contain the full file path including filename.",
    default="True",
    show_default=True,
    is_flag=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, workflow_id, file_local_path, use_default_filename=True):
    """Exports a workflow in JSON format to a given local path.

Output:

    
    """
    return ctx.gi.workflows.export_workflow_to_local_path(workflow_id, file_local_path, use_default_filename=use_default_filename)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('get_tool_panel')
@pass_context
@custom_exception
@list_output
def cli(ctx):
    """Get a list of available tool elements in Galaxy's configured toolbox.

Output:

    List containing tools (if not in sections) or tool sections
                 with nested tool descriptions.

        .. seealso:: bioblend.galaxy.toolshed.get_repositories()
    """
    return ctx.gi.tools.get_tool_panel()



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('get_workflows')
@click.option(
    "--workflow_id",
    help="Encoded workflow ID (incompatible with ``name``)",
    type=str
)
@click.option(
    "--name",
    help="Filter by name of workflow (incompatible with ``workflow_id``). If multiple names match the given name, all the workflows matching the argument will be returned.",
    type=str
)
@click.option(
    "--published",
    help="if ``True``, return also published workflows",
    is_flag=True
)
@pass_context
@custom_exception
@list_output
def cli(ctx, workflow_id="", name="", published=False):
    """Get all workflows or filter the specific one(s) via the provided ``name`` or ``workflow_id``. Provide only one argument, ``name`` or ``workflow_id``, but not both.

Output:

    A list of workflow dicts.
                 For example::

                   [{u'id': u'92c56938c2f9b315',
                     u'name': u'Simple',
                     u'url': u'/api/workflows/92c56938c2f9b315'}]
    """
    return ctx.gi.workflows.get_workflows(workflow_id=workflow_id, name=name, published=published)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('get_status')
@click.argument("history_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, history_id):
    """Returns the state of this history

Output:

    A dict documenting the current state of the history. Has the following keys:
            'state' = This is the current state of the history, such as ok, error, new etc.
            'state_details' = Contains individual statistics for various dataset states.
            'percent_complete' = The overall number of datasets processed to completion.
    """
    return ctx.gi.histories.get_status(history_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('reload_data_table')
@click.argument("data_table_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, data_table_id):
    """Reload a data table.

Output:

    A description of the given data table and its content.
          For example::

            {"columns": ["value", "dbkey", "name", "path"],
             "fields": [["test id",
               "test",
               "test name",
               "/opt/galaxy-dist/tool-data/test/seq/test id.fa"]],
             "model_class": "TabularToolDataTable",
             "name": "all_fasta"}
    """
    return ctx.gi.tool_data.reload_data_table(data_table_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('delete_dataset_collection')
@click.argument("history_id", type=str)
@click.argument("dataset_collection_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, history_id, dataset_collection_id):
    """Mark corresponding dataset collection as deleted.

Output:

    
    """
    return ctx.gi.histories.delete_dataset_collection(history_id, dataset_collection_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('undelete_history')
@click.argument("history_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, history_id):
    """Undelete a history

Output:

    
    """
    return ctx.gi.histories.undelete_history(history_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('set_library_permissions')
@click.argument("library_id", type=str)
@click.option(
    "--access_in",
    help="list of role ids",
    type=str,
    multiple=True
)
@click.option(
    "--modify_in",
    help="list of role ids",
    type=str,
    multiple=True
)
@click.option(
    "--add_in",
    help="list of role ids",
    type=str,
    multiple=True
)
@click.option(
    "--manage_in",
    help="list of role ids",
    type=str,
    multiple=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, library_id, access_in="", modify_in="", add_in="", manage_in=""):
    """Set the permissions for a library.  Note: it will override all security for this library even if you leave out a permission type.

Output:

    
    """
    return ctx.gi.libraries.set_library_permissions(library_id, access_in=access_in, modify_in=modify_in, add_in=add_in, manage_in=manage_in)



import os

import click

from bioblend import galaxy
from parsec.cli import pass_context
from parsec import config
from parsec.io import warn, info

CONFIG_TEMPLATE = """## Parsec Global Configuration File.
# Each stanza should contian a single galaxy server to control.
#
# You can set the key __default to the name of a default instance
__default: local

local:
    key: "%(key)s"
    url: "%(url)s"
"""

SUCCESS_MESSAGE = (
    "Ready to go! Type `parsec` to get a list of commands you can execute."
)


@click.command("config_init")
@click.option(
    "--url",
    help="your Galaxy's URL",
    type=str
)
@click.option(
    "--api_key",
    help="your Galaxy API Key",
    type=str
)
@pass_context
def cli(ctx, url=None, api_key=None, admin=False, **kwds):
    """Help initialize global configuration (in home directory)
    """
    # TODO: prompt for values someday.
    click.echo("""
Welcome to
      ____   ____ _   _____   _____  ___   _____
     / __ \ / __ `/  / ___/  / ___/ / _ \ / ___/
    / /_/ // /_/ /  / /     (__  ) /  __// /__
   / .___/ \__,_/  /_/     /____/  \___/ \___/
  /_/ Galaxy at the Speed of Light
""")
    config_path = config.global_config_path()

    if os.path.exists(config_path):
        info("Your parsec configuration already exists. Please edit it instead: %s" % config_path)
        return 0

    while True:
        galaxy_url = url
        if url is None or len(url) == 0 :
            galaxy_url = click.prompt("Please entry your Galaxy's URL")
        galaxy_key = api_key
        if api_key is None or len(api_key) == 0 :
            galaxy_key = click.prompt("Please entry your Galaxy API Key")
        info("Testing connection...")
        gi = galaxy.GalaxyInstance(galaxy_url, galaxy_key)
        try:
            conf = gi.config.get_config()
            if 'version_major' in conf:
                # Ok, success
                info("Ok! Everything looks good.")
                break
            else:
                warn("Error, we could not access the configuration data for your instance.")
                should_break = click.prompt("Continue despite inability to contact this Galaxy Instance? [y/n]")
                if should_break in ('Y', 'y'):
                    break
        except Exception as e:
            warn_msg = ("Error, we could not access the configuration data for your instance. "
                        "The server responded with error code %s. If your galaxy uses remote_user "
                        "authentication (i.e. as username + password is requested if you try to curl "
                        "or wget %s.) If this is the case, you may need to add an exception for the "
                        "Galaxy API. Please see https://galaxyproject.org/admin/config/apache-external-user-auth/ "
                        "or https://galaxyproject.org/admin/config/nginx-external-user-auth/ for more information.)")
            warn(warn_msg, e.status_code, galaxy_url)
            should_break = click.prompt("Continue despite inability to contact this Galaxy Instance? [y/n]")
            if should_break in ('Y', 'y'):
                break

    if os.path.exists(config_path):
        warn("File %s already exists, refusing to overwrite." % config_path)
        return -1
    with open(config_path, "w") as f:
        f.write(
            CONFIG_TEMPLATE % {
                'key': galaxy_key,
                'url': galaxy_url,
            })
        info(SUCCESS_MESSAGE)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('create_history_tag')
@click.argument("history_id", type=str)
@click.argument("tag", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, history_id, tag):
    """Create history tag

Output:

    A dictionary with information regarding the tag.
          For example::

            {'id': 'f792763bee8d277a',
             'model_class': 'HistoryTagAssociation',
             'user_tname': 'NGS_PE_RUN',
             'user_value': None}
    """
    return ctx.gi.histories.create_history_tag(history_id, tag)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('export_workflow_dict')
@click.argument("workflow_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, workflow_id):
    """Exports a workflow.

Output:

    Dictionary representing the requested workflow
    """
    return ctx.gi.workflows.export_workflow_dict(workflow_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('update_repository')
@click.argument("id", type=str)
@click.argument("tar_ball_path", type=str)
@click.option(
    "--commit_message",
    help="Commit message used for the underlying Mercurial repository backing Tool Shed repository.",
    type=str
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, id, tar_ball_path, commit_message=""):
    """Update the contents of a Tool Shed repository with specified tar ball.

Output:

    Returns a dictionary that includes repository content warnings.
          Most valid uploads will result in no such warning and an exception
          will be raised generally if there are problems.
          For example a successful upload will look like::

            {u'content_alert': u'',
             u'message': u''}

        .. versionadded:: 0.5.2
    """
    return ctx.gi.repositories.update_repository(id, tar_ball_path, commit_message=commit_message)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('get_groups')
@pass_context
@custom_exception
@list_output
def cli(ctx):
    """Get all (not deleted) groups.

Output:

    A list of dicts with details on individual groups.
          For example::

            [{'id': '33abac023ff186c2',
              'model_class': 'Group',
              'name': 'Listeria',
              'url': '/api/groups/33abac023ff186c2'},
             {'id': '73187219cd372cf8',
              'model_class': 'Group',
              'name': 'LPN',
              'url': '/api/groups/73187219cd372cf8'}]
    """
    return ctx.gi.groups.get_groups()



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('show_form')
@click.argument("form_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, form_id):
    """Get details of a given form.

Output:

    A description of the given form.
          For example::

            {u'desc': u'here it is ',
             u'fields': [],
             u'form_definition_current_id': u'f2db41e1fa331b3e',
             u'id': u'f2db41e1fa331b3e',
             u'layout': [],
             u'model_class': u'FormDefinition',
             u'name': u'First form',
             u'url': u'/api/forms/f2db41e1fa331b3e'}
    """
    return ctx.gi.forms.show_form(form_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('get_users')
@click.option(
    "--deleted",
    help=""
)
@click.option(
    "--f_email",
    help="filter for user emails. The filter will be active for non-admin users only if the Galaxy instance has the ``expose_user_email`` option set to ``True`` in the ``config/galaxy.ini`` configuration file. This parameter is silently ignored for non-admin users in Galaxy ``release_15.01`` and earlier.",
    type=str
)
@click.option(
    "--f_name",
    help="filter for user names. The filter will be active for non-admin users only if the Galaxy instance has the ``expose_user_name`` option set to ``True`` in the ``config/galaxy.ini`` configuration file. This parameter is silently ignored in Galaxy ``release_15.10`` and earlier.",
    type=str
)
@click.option(
    "--f_any",
    help="filter for user email or name. Each filter will be active for non-admin users only if the Galaxy instance has the corresponding ``expose_user_*`` option set to ``True`` in the ``config/galaxy.ini`` configuration file. This parameter is silently ignored in Galaxy ``release_15.10`` and earlier.",
    type=str
)
@pass_context
@custom_exception
@list_output
def cli(ctx, deleted=False, f_email="", f_name="", f_any=""):
    """Get a list of all registered users. If ``deleted`` is set to ``True``, get a list of deleted users.

Output:

    a list of dicts with user details.
                 For example::

                   [{u'email': u'a_user@example.com',
                     u'id': u'dda47097d9189f15',
                     u'url': u'/api/users/dda47097d9189f15'}]
    """
    return ctx.gi.users.get_users(deleted=deleted, f_email=f_email, f_name=f_name, f_any=f_any)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('install_genome')
@click.option(
    "--func",
    help="Allowed values: 'download', Download and index; 'index', Index only",
    default="download",
    show_default=True,
    type=str
)
@click.option(
    "--source",
    help="Data source for this build. Can be: UCSC, Ensembl, NCBI, URL",
    type=str
)
@click.option(
    "--dbkey",
    help="DB key of the build to download, ignored unless 'UCSC' is specified as the source",
    type=str
)
@click.option(
    "--ncbi_name",
    help="NCBI's genome identifier, ignored unless NCBI is specified as the source",
    type=str
)
@click.option(
    "--ensembl_dbkey",
    help="Ensembl's genome identifier, ignored unless Ensembl is specified as the source",
    type=str
)
@click.option(
    "--url_dbkey",
    help="DB key to use for this build, ignored unless URL is specified as the source",
    type=str
)
@click.option(
    "--indexers",
    help="POST array of indexers to run after downloading (indexers[] = first, indexers[] = second, ...)",
    type=str,
    multiple=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, func="download", source="", dbkey="", ncbi_name="", ensembl_dbkey="", url_dbkey="", indexers=""):
    """Download and/or index a genome.

Output:

    dict( status: 'ok', job: <job ID> )
                 If error:
                 dict( status: 'error', error: <error message> )
    """
    return ctx.gi.genomes.install_genome(func=func, source=source, dbkey=dbkey, ncbi_name=ncbi_name, ensembl_dbkey=ensembl_dbkey, url_dbkey=url_dbkey, indexers=indexers)



from __future__ import absolute_import
import os
import yaml

DEFAULT_CONFIG = {
}

_config_path = os.environ.get(
    "PARSEC_GLOBAL_CONFIG_PATH",
    "~/.parsec.yml"
)
_config_path = os.path.expanduser(_config_path)
DEFAULT_CONFIG['config_path'] = _config_path


def global_config_path():
    return DEFAULT_CONFIG['config_path']


def set_global_config_path(config_path):
    DEFAULT_CONFIG['config_path'] = config_path


def read_global_config():
    config_path = global_config_path()
    if not os.path.exists(config_path):
        return DEFAULT_CONFIG

    with open(config_path) as f:
        return yaml.safe_load(f)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('download_dataset')
@click.argument("history_id")
@click.argument("dataset_id")
@click.argument("file_path")
@click.option(
    "--use_default_filename",
    help="",
    default="True",
    show_default=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, history_id, dataset_id, file_path, use_default_filename=True):
    """.. deprecated:: 0.8.0 Use :meth:`~bioblend.galaxy.datasets.DatasetClient.download_dataset` instead.

Output:

    
    """
    return ctx.gi.histories.download_dataset(history_id, dataset_id, file_path, use_default_filename=use_default_filename)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('get_repositories')
@pass_context
@custom_exception
@list_output
def cli(ctx):
    """Get a list of all the repositories in a Galaxy Tool Shed.

Output:

    Returns a list of dictionaries containing information about
          repositories present in the Tool Shed.
          For example::

            [{u'category_ids': [u'c1df3132f6334b0e', u'f6d7b0037d901d9b'],
              u'deleted': False,
              u'deprecated': False,
              u'description': u'Order Contigs',
              u'homepage_url': u'',
              u'id': u'287bd69f724b99ce',
              u'name': u'best_tool_ever',
              u'owner': u'billybob',
              u'private': False,
              u'remote_repository_url': u'',
              u'times_downloaded': 0,
              u'type': u'unrestricted',
              u'url': u'/api/repositories/287bd69f724b99ce',
              u'user_id': u'5cefd48bc04af6d4'}]

        .. versionchanged:: 0.4.1
          Changed method name from ``get_tools`` to ``get_repositories`` to
          better align with the Tool Shed concepts.
    """
    return ctx.gi.repositories.get_repositories()



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('get_permissions')
@click.argument("folder_id", type=str)
@click.argument("scope", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, folder_id, scope):
    """Get the permissions of a folder.

Output:

    dictionary including details of the folder
    """
    return ctx.gi.folders.get_permissions(folder_id, scope)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, str_output


@click.command('update_quota')
@click.argument("quota_id", type=str)
@click.option(
    "--name",
    help="Name for the new quota. This must be unique within a Galaxy instance.",
    type=str
)
@click.option(
    "--description",
    help="Quota description. If you supply this parameter, but not the name, an error will be thrown.",
    type=str
)
@click.option(
    "--amount",
    help="Quota size (E.g. ``10000MB``, ``99 gb``, ``0.2T``, ``unlimited``)",
    type=str
)
@click.option(
    "--operation",
    help="One of (``+``, ``-``, ``=``). If you wish to change this value, you must also provide the ``amount``, otherwise it will not take effect.",
    type=str
)
@click.option(
    "--default",
    help="Whether or not this is a default quota. Valid values are ``no``, ``unregistered``, ``registered``. Calling this method with ``default=\"no\"`` on a non-default quota will throw an error. Not passing this parameter is equivalent to passing ``no``.",
    default="no",
    show_default=True,
    type=str
)
@click.option(
    "--in_users",
    help="A list of user IDs or user emails.",
    type=str,
    multiple=True
)
@click.option(
    "--in_groups",
    help="A list of group IDs or names.",
    type=str,
    multiple=True
)
@pass_context
@custom_exception
@str_output
def cli(ctx, quota_id, name="", description="", amount="", operation="", default="no", in_users=None, in_groups=None):
    """Update an existing quota

Output:

    A semicolon separated list of changes to the quota.
          For example::

            "Quota 'Testing-A' has been renamed to 'Testing-B'; Quota 'Testing-e' is now '-100.0 GB'; Quota 'Testing-B' is now the default for unregistered users"
    """
    return ctx.gi.quotas.update_quota(quota_id, name=name, description=description, amount=amount, operation=operation, default=default, in_users=in_users, in_groups=in_groups)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('show_invocation')
@click.argument("workflow_id", type=str)
@click.argument("invocation_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, workflow_id, invocation_id):
    """Get a workflow invocation object representing the scheduling of a workflow. This object may be sparse at first (missing inputs and invocation steps) and will become more populated as the workflow is actually scheduled.

Output:

    The workflow invocation.
          For example::

            {u'history_id': u'2f94e8ae9edff68a',
             u'id': u'df7a1f0c02a5b08e',
             u'inputs': {u'0': {u'id': u'a7db2fac67043c7e',
               u'src': u'hda',
               u'uuid': u'7932ffe0-2340-4952-8857-dbaa50f1f46a'}},
             u'model_class': u'WorkflowInvocation',
             u'state': u'ready',
             u'steps': [{u'action': None,
               u'id': u'd413a19dec13d11e',
               u'job_id': None,
               u'model_class': u'WorkflowInvocationStep',
               u'order_index': 0,
               u'state': None,
               u'update_time': u'2015-10-31T22:00:26',
               u'workflow_step_id': u'cbbbf59e8f08c98c',
               u'workflow_step_label': None,
               u'workflow_step_uuid': u'b81250fd-3278-4e6a-b269-56a1f01ef485'},
              {u'action': None,
               u'id': u'2f94e8ae9edff68a',
               u'job_id': u'e89067bb68bee7a0',
               u'model_class': u'WorkflowInvocationStep',
               u'order_index': 1,
               u'state': u'new',
               u'update_time': u'2015-10-31T22:00:26',
               u'workflow_step_id': u'964b37715ec9bd22',
               u'workflow_step_label': None,
               u'workflow_step_uuid': u'e62440b8-e911-408b-b124-e05435d3125e'}],
             u'update_time': u'2015-10-31T22:00:26',
             u'uuid': u'c8aa2b1c-801a-11e5-a9e5-8ca98228593c',
             u'workflow_id': u'03501d7626bd192f'}
    """
    return ctx.gi.workflows.show_invocation(workflow_id, invocation_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('import_workflow_json')
@click.argument("workflow_json", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, workflow_json):
    """.. deprecated:: 0.9.0 Use :meth:`import_workflow_dict` instead.

Output:

    
    """
    return ctx.gi.workflows.import_workflow_json(json_loads(workflow_json))



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('get_data_tables')
@pass_context
@custom_exception
@list_output
def cli(ctx):
    """Get the list of all data tables.

Output:

    A list of dicts with details on individual data tables.
          For example::

            [{"model_class": "TabularToolDataTable", "name": "fasta_indexes"},
             {"model_class": "TabularToolDataTable", "name": "bwa_indexes"}]
    """
    return ctx.gi.tool_data.get_data_tables()



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('upload_dataset_from_library')
@click.argument("history_id", type=str)
@click.argument("lib_dataset_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, history_id, lib_dataset_id):
    """Upload a dataset into the history from a library. Requires the library dataset ID, which can be obtained from the library contents.

Output:

    
    """
    return ctx.gi.histories.upload_dataset_from_library(history_id, lib_dataset_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('show_library')
@click.argument("library_id", type=str)
@click.option(
    "--contents",
    help="True if want to get contents of the library (rather than just the library details)",
    is_flag=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, library_id, contents=False):
    """Get information about a library.

Output:

    details of the given library
    """
    return ctx.gi.libraries.show_library(library_id, contents=contents)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('create_repository')
@click.argument("name", type=str)
@click.argument("synopsis", type=str)
@click.option(
    "--description",
    help="Optional description of the repository",
    type=str
)
@click.option(
    "--type",
    help="type of the repository. One of \"unrestricted\", \"repository_suite_definition\", or \"tool_dependency_definition\"",
    default="unrestricted",
    show_default=True,
    type=str
)
@click.option(
    "--remote_repository_url",
    help="Remote URL (e.g. GitHub/Bitbucket repository)",
    type=str
)
@click.option(
    "--homepage_url",
    help="Upstream's homepage for the project",
    type=str
)
@click.option(
    "--category_ids",
    help="List of encoded category IDs",
    type=str,
    multiple=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, name, synopsis, description="", type="unrestricted", remote_repository_url="", homepage_url="", category_ids=""):
    """Create a new repository in a Tool Shed.

Output:

    a dictionary containing information about the new repository.
          For example::

            {"deleted": false,
             "deprecated": false,
             "description": "new_synopsis",
             "homepage_url": "https://github.com/galaxyproject/",
             "id": "8cf91205f2f737f4",
             "long_description": "this is some repository",
             "model_class": "Repository",
             "name": "new_repo_17",
             "owner": "qqqqqq",
             "private": false,
             "remote_repository_url": "https://github.com/galaxyproject/tools-devteam",
             "times_downloaded": 0,
             "type": "unrestricted",
             "user_id": "adb5f5c93f827949"}
    """
    return ctx.gi.repositories.create_repository(name, synopsis, description=description, type=type, remote_repository_url=remote_repository_url, homepage_url=homepage_url, category_ids=category_ids)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import glob

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

readme = open('README.rst').read()

requirements = [
    'Click>=6.7',
    'bioblend==0.12.0',
    'wrapt',
    'pyyaml',
    'justbackoff',
    'xunit-wrapper>=0.12',
    'future',
]

test_requirements = [
    # TODO: put package test requirements here
]

version = '1.12.1'
subpackages = [x.replace('/', '.') for x in glob.glob('parsec/commands/*') if not x.endswith('.py')]

setup(
    name='galaxy-parsec',
    version=version,
    description='Command-line utilities to assist in interacting with Galaxy servers (http://galaxyproject.org/).',
    long_description=readme,
    author='Galaxy Project and Community',
    author_email='parsec@hx42.org',
    url='https://github.com/galaxy-iuc/parsec',
    packages=[
        'parsec',
        'parsec.commands',
    ] + subpackages,
    entry_points='''
        [console_scripts]
        parsec=parsec.cli:parsec
    ''',
    package_dir={'parsec': 'parsec'},
    install_requires=requirements,
    license="AFL",
    keywords='parsec',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Environment :: Console',
        'License :: OSI Approved :: MIT License',
        'Operating System :: POSIX',
        'Natural Language :: English',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    test_suite='tests',
    tests_require=test_requirements
)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('download_history')
@click.argument("history_id", type=str)
@click.argument("jeha_id", type=str)
@click.argument("outf", type=click.File('rb+'))
@click.option(
    "--chunk_size",
    help="how many bytes at a time should be read into memory",
    default="4096",
    show_default=True,
    type=int
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, history_id, jeha_id, outf, chunk_size=4096):
    """Download a history export archive.  Use :meth:`export_history` to create an export.

Output:

    
    """
    return ctx.gi.histories.download_history(history_id, jeha_id, outf, chunk_size=chunk_size)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('show_invocation_step')
@click.argument("workflow_id", type=str)
@click.argument("invocation_id", type=str)
@click.argument("step_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, workflow_id, invocation_id, step_id):
    """See the details of a particular workflow invocation step.

Output:

    The workflow invocation step.
          For example::

            {u'action': None,
             u'id': u'63cd3858d057a6d1',
             u'job_id': None,
             u'model_class': u'WorkflowInvocationStep',
             u'order_index': 2,
             u'state': None,
             u'update_time': u'2015-10-31T22:11:14',
             u'workflow_step_id': u'52e496b945151ee8',
             u'workflow_step_label': None,
             u'workflow_step_uuid': u'4060554c-1dd5-4287-9040-8b4f281cf9dc'}
    """
    return ctx.gi.workflows.show_invocation_step(workflow_id, invocation_id, step_id)



import click
from parsec.commands.toolshed.get_repositories import cli as func0
from parsec.commands.toolshed.install_repository_revision import cli as func1
from parsec.commands.toolshed.show_repository import cli as func2

@click.group()
def cli():
    pass

cli.add_command(func0)
cli.add_command(func1)
cli.add_command(func2)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('show_role')
@click.argument("role_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, role_id):
    """Display information on a single role

Output:

    A description of role
          For example::

            {"description": "Private Role for Foo",
             "id": "f2db41e1fa331b3e",
             "model_class": "Role",
             "name": "Foo",
             "type": "private",
             "url": "/api/roles/f2db41e1fa331b3e"}
    """
    return ctx.gi.roles.show_role(role_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('delete_data_table')
@click.argument("data_table_id", type=str)
@click.argument("values", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, data_table_id, values):
    """Delete an item from a data table.

Output:

    
    """
    return ctx.gi.tool_data.delete_data_table(data_table_id, values)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('show_dataset')
@click.argument("dataset_id", type=str)
@click.option(
    "--deleted",
    help="Whether to return results for a deleted dataset",
    is_flag=True
)
@click.option(
    "--hda_ldda",
    help="Whether to show a history dataset ('hda' - the default) or library dataset ('ldda').",
    default="hda",
    show_default=True,
    type=str
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, dataset_id, deleted=False, hda_ldda="hda"):
    """Get details about a given dataset. This can be a history or a library dataset.

Output:

    
    """
    return ctx.gi.datasets.show_dataset(dataset_id, deleted=deleted, hda_ldda=hda_ldda)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('copy_from_dataset')
@click.argument("library_id", type=str)
@click.argument("dataset_id", type=str)
@click.option(
    "--folder_id",
    help="id of the folder where to place the uploaded files. If not provided, the root folder will be used",
    type=str
)
@click.option(
    "--message",
    help="message for copying action",
    type=str
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, library_id, dataset_id, folder_id="", message=""):
    """Copy a Galaxy dataset into a library.

Output:

    
    """
    return ctx.gi.libraries.copy_from_dataset(library_id, dataset_id, folder_id=folder_id, message=message)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('show_category')
@click.argument("category_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, category_id):
    """Get details of a given category.

Output:

    details of the given category
    """
    return ctx.gi.categories.show_category(category_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('run_tool')
@click.argument("history_id", type=str)
@click.argument("tool_id", type=str)
@click.argument("tool_inputs", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, history_id, tool_id, tool_inputs):
    """Runs tool specified by ``tool_id`` in history indicated by ``history_id`` with inputs from ``dict`` ``tool_inputs``.

Output:

    
    """
    return ctx.gi.tools.run_tool(history_id, tool_id, json_loads(tool_inputs))



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('delete_dataset')
@click.argument("history_id", type=str)
@click.argument("dataset_id", type=str)
@click.option(
    "--purge",
    help="if ``True``, also purge (permanently delete) the dataset",
    is_flag=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, history_id, dataset_id, purge=False):
    """Mark corresponding dataset as deleted.

Output:

    
    """
    return ctx.gi.histories.delete_dataset(history_id, dataset_id, purge=purge)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('get_sniffers')
@pass_context
@custom_exception
@list_output
def cli(ctx):
    """Get the list of all installed sniffers.

Output:

    A list of sniffer names.
          For example::

            [u'galaxy.datatypes.tabular:Vcf',
             u'galaxy.datatypes.binary:TwoBit',
             u'galaxy.datatypes.binary:Bam',
             u'galaxy.datatypes.binary:Sff',
             u'galaxy.datatypes.xml:Phyloxml',
             u'galaxy.datatypes.xml:GenericXml',
             u'galaxy.datatypes.sequence:Maf',
             u'galaxy.datatypes.sequence:Lav',
             u'galaxy.datatypes.sequence:csFasta']
    """
    return ctx.gi.datatypes.get_sniffers()



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('get_config')
@pass_context
@custom_exception
@list_output
def cli(ctx):
    """Get a list of attributes about the Galaxy instance. More attributes will be present if the user is an admin.

Output:

    A list of attributes.
          For example::

            {u'allow_library_path_paste': False,
             u'allow_user_creation': True,
             u'allow_user_dataset_purge': True,
             u'allow_user_deletion': False,
             u'enable_unique_workflow_defaults': False,
             u'ftp_upload_dir': u'/SOMEWHERE/galaxy/ftp_dir',
             u'ftp_upload_site': u'galaxy.com',
             u'library_import_dir': u'None',
             u'logo_url': None,
             u'support_url': u'https://galaxyproject.org/support',
             u'terms_url': None,
             u'user_library_import_dir': None,
             u'wiki_url': u'https://galaxyproject.org/'}
    """
    return ctx.gi.config.get_config()



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('upload_file')
@click.argument("path", type=str)
@click.argument("history_id", type=str)
@click.option(
    "--dbkey",
    help="(optional) genome dbkey",
    type=str
)
@click.option(
    "--file_name",
    help="(optional) name of the new history dataset",
    type=str
)
@click.option(
    "--file_type",
    help="Galaxy datatype for the new dataset, default is auto",
    type=str
)
@click.option(
    "--space_to_tab",
    help="whether to convert spaces to tabs. Default is False. Applicable only if to_posix_lines is True",
    is_flag=True
)
@click.option(
    "--to_posix_lines",
    help="if True, convert universal line endings to POSIX line endings. Default is True. Set to False if you upload a gzip, bz2 or zip archive containing a binary file",
    is_flag=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, path, history_id, dbkey=None, file_name=None, file_type=None, space_to_tab=None, to_posix_lines=None):
    """Upload the file specified by ``path`` to the history specified by ``history_id``.

Output:

    
    """
    kwargs = {}
    if dbkey and len(dbkey) > 0:
        kwargs['dbkey'] = dbkey
    if file_name and len(file_name) > 0:
        kwargs['file_name'] = file_name
    if file_type and len(file_type) > 0:
        kwargs['file_type'] = file_type
    if space_to_tab is not None:
        kwargs['space_to_tab'] = space_to_tab
    if to_posix_lines is not None:
        kwargs['to_posix_lines'] = to_posix_lines

    return ctx.gi.tools.upload_file(path, history_id, **kwargs)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, list_output


@click.command('get_tools')
@click.option(
    "--tool_id",
    help="id of the requested tool",
    type=str
)
@click.option(
    "--name",
    help="name of the requested tool(s)",
    type=str
)
@click.option(
    "--trackster",
    help="if True, only tools that are compatible with Trackster are returned",
    is_flag=True
)
@pass_context
@custom_exception
@list_output
def cli(ctx, tool_id="", name="", trackster=""):
    """Get all tools or filter the specific one(s) via the provided ``name`` or ``tool_id``. Provide only one argument, ``name`` or ``tool_id``, but not both.

Output:

    List of tool descriptions.

        .. seealso:: bioblend.galaxy.toolshed.get_repositories()
    """
    return ctx.gi.tools.get_tools(tool_id=tool_id, name=name, trackster=trackster)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('delete_library')
@click.argument("library_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, library_id):
    """Delete a data library.

Output:

    
    """
    return ctx.gi.libraries.delete_library(library_id)



import click
from parsec.commands.utils.wait_on_invocation import cli as func0
from parsec.commands.utils.xunit_xargs import cli as func1
from parsec.commands.utils.cmp import cli as func2
from parsec.commands.utils.library_recurse import cli as func3

@click.group()
def cli():
    pass

cli.add_command(func0)
cli.add_command(func1)
cli.add_command(func2)
cli.add_command(func3)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('delete_workflow')
@click.argument("workflow_id", type=str)
@pass_context
@custom_exception
@dict_output
def cli(ctx, workflow_id):
    """Delete a workflow identified by `workflow_id`.

Output:

    
    """
    return ctx.gi.workflows.delete_workflow(workflow_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('update_library_dataset')
@click.argument("dataset_id", type=str)
@click.option(
    "--file_ext",
    help="Replace library dataset extension (must exist in the Galaxy registry)",
    type=str
)
@click.option(
    "--genome_build",
    help="Replace library dataset genome build (dbkey)",
    type=str
)
@click.option(
    "--misc_info",
    help="Replace library dataset misc_info with given string",
    type=str
)
@click.option(
    "--name",
    help="Replace library dataset name with the given string",
    type=str
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, dataset_id, file_ext=None, genome_build=None, misc_info=None, name=None):
    """Update library dataset metadata. Some of the attributes that can be modified are documented below.

Output:

    details of the updated dataset
    """
    kwargs = {}
    if file_ext and len(file_ext) > 0:
        kwargs['file_ext'] = file_ext
    if genome_build and len(genome_build) > 0:
        kwargs['genome_build'] = genome_build
    if misc_info and len(misc_info) > 0:
        kwargs['misc_info'] = misc_info
    if name and len(name) > 0:
        kwargs['name'] = name

    return ctx.gi.libraries.update_library_dataset(dataset_id, **kwargs)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import custom_exception, dict_output


@click.command('upload_file_from_server')
@click.argument("library_id", type=str)
@click.argument("server_dir", type=str)
@click.option(
    "--folder_id",
    help="id of the folder where to place the uploaded files. If not provided, the root folder will be used",
    type=str
)
@click.option(
    "--file_type",
    help="Galaxy file format name",
    default="auto",
    show_default=True,
    type=str
)
@click.option(
    "--dbkey",
    help="Dbkey",
    default="?",
    show_default=True,
    type=str
)
@click.option(
    "--link_data_only",
    help="either 'copy_files' (default) or 'link_to_files'. Setting to 'link_to_files' symlinks instead of copying the files",
    type=str
)
@click.option(
    "--roles",
    help="???",
    type=str
)
@click.option(
    "--preserve_dirs",
    help="Indicate whether to preserve the directory structure when importing dir",
    is_flag=True
)
@click.option(
    "--tag_using_filenames",
    help="Indicate whether to generate dataset tags from filenames",
    default="True",
    show_default=True,
    is_flag=True
)
@pass_context
@custom_exception
@dict_output
def cli(ctx, library_id, server_dir, folder_id="", file_type="auto", dbkey="?", link_data_only="", roles="", preserve_dirs=False, tag_using_filenames=True):
    """Upload all files in the specified subdirectory of the Galaxy library import directory to a library.

Output:

    
    """
    return ctx.gi.libraries.upload_file_from_server(library_id, server_dir, folder_id=folder_id, file_type=file_type, dbkey=dbkey, link_data_only=link_data_only, roles=roles, preserve_dirs=preserve_dirs, tag_using_filenames=tag_using_filenames)
